/**
 * Scriptable iOS Type Definitions
 * 
 * @file Auto-generated abstract class definitions for Scriptable iOS
 * @source @types/scriptable-ios@1.7.7
 * @module scriptable-abstract
 * @generated 2024-12-21T14:36:04.921Z
 * @license MIT
 */
class ScriptableBase {
  static type;
  _state = {};
  constructor(state) {
    this.setState(state ?? {});
  }
  _get(key) {
    return this._state[key];
  }
  _set(key, value) {
    this._state[key] = value;
  }
  _invoke(method, _args) {
    throw new Error(`Method '${String(method)}' not implemented`);
  }
  static _invokeStatic(method, _args) {
    throw new Error(`Static method ${method} not implemented`);
  }
  get state() {
    return this._state;
  }
  setState(state) {
    const newState = typeof state === "function" ? state(this._state) : state;
    this._state = { ...this._state, ...newState };
    return this;
  }
}
class ScriptableObject extends ScriptableBase {
}
class ScriptableGlobal extends ScriptableBase {
}
class AbsAlert extends ScriptableObject {
  static type = "Alert";
  get title() {
    return this._get("title");
  }
  set title(value) {
    this._set("title", value);
  }
  get message() {
    return this._get("message");
  }
  set message(value) {
    this._set("message", value);
  }
  /**
     * _Adds an action to the alert._
     *
     * Adds an action button to the alert. To check if an action was selected, you should use the first parameter provided when the promise returned by presentAlert() and presentSheet()
     * is resolved.
     * @param title - Title of the action.
     * @see https://docs.scriptable.app/alert/#-addaction
     */
  addAction(title) {
    return this._invoke("addAction", Array.from(arguments));
  }
  /**
     * _Adds a destructive action to the alert._
     *
     * Destructive action titles have a red text color, signaling that the action may modify or delete data.
     * @param title - Title of the action.
     * @see https://docs.scriptable.app/alert/#-adddestructiveaction
     */
  addDestructiveAction(title) {
    return this._invoke("addDestructiveAction", Array.from(arguments));
  }
  /**
     * _Adds a cancel action to the alert._
     *
     * Adds a cancel action to the alert. When a cancel action is selected, the index provided by presentAlert() or presentSheet() will always be -1. Please note that when running on the
     * iPad and presenting using presentSheet(), the action will not be shown in the list of actions. The operation is cancelled by tapping outside the sheet.
     *
     * An alert can only contain a single cancel action. Attempting to add more cancel actions will remove any previously added cancel actions.
     * @param title - Title of the action.
     * @see https://docs.scriptable.app/alert/#-addcancelaction
     */
  addCancelAction(title) {
    return this._invoke("addCancelAction", Array.from(arguments));
  }
  /**
     * _Adds a text field prompting for user input._
     *
     * Adds a text field to the alert controller prompting for user input. Retrieve the value for the text field using textFieldValue() and supply the index of the text field. Indices for
     * text fields are assigned in the same order as they are added to the alert starting at 0.
     *
     * Text fields are not supported when using the sheet presentation.
     * @param placeholder - Optional placeholder that will be displayed when the text field is empty.
     * @param text - Optional default value for the text field.
     * @see https://docs.scriptable.app/alert/#-addtextfield
     */
  addTextField(placeholder, text) {
    return this._invoke("addTextField", Array.from(arguments));
  }
  /**
     * _Adds a secure text field prompting for user input._
     *
     * Adds a secure text field to the alert controller prompting for user input. Values entered into a secure text field will be hidden behind dots. Retrieve the value for the text field
     * using textFieldValue() and supply the index of the text field. Indices for text fields are assigned in the same order as they are added to the alert starting at 0.
     * @param placeholder - Optional placeholder that will be displayed when the text field is empty.
     * @param text - Optional default value for the text field.
     * @see https://docs.scriptable.app/alert/#-addsecuretextfield
     */
  addSecureTextField(placeholder, text) {
    return this._invoke("addSecureTextField", Array.from(arguments));
  }
  /**
     * _Retrieves value of a text field._
     *
     * Retrieves the value of a text field added using addTextField() or addSecureTextField(). Indices for text fields are assigned in the same order as they are added to the alert
     * starting at 0.
     * @param index - Index of text field to retrieve for value.
     * @see https://docs.scriptable.app/alert/#-textfieldvalue
     */
  textFieldValue(index) {
    return this._invoke("textFieldValue", Array.from(arguments));
  }
  /**
     * _Presents the alert modally._
     *
     * This is a shorthand for presentAlert().
     * @see https://docs.scriptable.app/alert/#-present
     */
  present() {
    return this._invoke("present", Array.from(arguments));
  }
  /**
     * _Presents the alert modally._
     * @see https://docs.scriptable.app/alert/#-presentalert
     */
  presentAlert() {
    return this._invoke("presentAlert", Array.from(arguments));
  }
  /**
     * _Presents the alert as a sheet._
     * @see https://docs.scriptable.app/alert/#-presentsheet
     */
  presentSheet() {
    return this._invoke("presentSheet", Array.from(arguments));
  }
}
class AbsCalendar extends ScriptableObject {
  static type = "Calendar";
  /**
     * _Fetches calendars for reminders._
     *
     * A calendar can only hold either reminders or events. Call this function to fetch all calendars that can hold reminders.
     * @see https://docs.scriptable.app/calendar/#forreminders
     */
  static forReminders() {
    return this._invokeStatic("forReminders", Array.from(arguments));
  }
  /**
     * _Fetches calendars for events._
     *
     * A calendar can only hold either reminders or events. Call this function to fetch all calendars that can hold events.
     * @see https://docs.scriptable.app/calendar/#forevents
     */
  static forEvents() {
    return this._invokeStatic("forEvents", Array.from(arguments));
  }
  /**
     * _Fetches a calendar that holds reminders._
     * @param title - Title of calendar.
     * @see https://docs.scriptable.app/calendar/#forremindersbytitle
     */
  static forRemindersByTitle(title) {
    return this._invokeStatic("forRemindersByTitle", Array.from(arguments));
  }
  /**
     * _Fetches a calendar that holds events._
     * @param title - Title of calendar.
     * @see https://docs.scriptable.app/calendar/#foreventsbytitle
     */
  static forEventsByTitle(title) {
    return this._invokeStatic("forEventsByTitle", Array.from(arguments));
  }
  /**
     * _Create a new calendar that holds reminders._
     *
     * This will create a new list for reminders in the Reminders app. The list is automatically saved so there is no need to call `save()` after creating the list.
     * @see https://docs.scriptable.app/calendar/#createforreminders
     */
  static createForReminders(title) {
    return this._invokeStatic("createForReminders", Array.from(arguments));
  }
  /**
     * _Find or create a new calendar that holds reminders._
     *
     * This will attempt to find a calendar for reminders with the specified name. If no calendar is found, a new calendar is created and the calendar will appear as a reminder list in
     * the Reminders app. If multiple calendars are found for the specified name, the first one will be returned. The list is automatically saved so there is no need to call `save()` in
     * the case the list was created.
     * @see https://docs.scriptable.app/calendar/#findorcreateforreminders
     */
  static findOrCreateForReminders(title) {
    return this._invokeStatic("findOrCreateForReminders", Array.from(arguments));
  }
  /**
     * _Default calendar for reminders._
     *
     * A calendar can only hold either reminders or events. Call this function to get the default calendar that can hold reminders.
     * @see https://docs.scriptable.app/calendar/#defaultforreminders
     */
  static defaultForReminders() {
    return this._invokeStatic("defaultForReminders", Array.from(arguments));
  }
  /**
     * _Default calendar for events._
     *
     * A calendar can only hold either reminders or events. Call this function to get the default calendar that can hold events.
     * @see https://docs.scriptable.app/calendar/#defaultforevents
     */
  static defaultForEvents() {
    return this._invokeStatic("defaultForEvents", Array.from(arguments));
  }
  /**
     * _Presents a view for picking calendars._
     * @param allowMultiple - Whether to allow picking multiple calenders. Defaults to false.
     * @see https://docs.scriptable.app/calendar/#presentpicker
     */
  static presentPicker(allowMultiple) {
    return this._invokeStatic("presentPicker", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get title() {
    return this._get("title");
  }
  set title(value) {
    this._set("title", value);
  }
  get isSubscribed() {
    return this._get("isSubscribed");
  }
  set isSubscribed(value) {
    this._set("isSubscribed", value);
  }
  get allowsContentModifications() {
    return this._get("allowsContentModifications");
  }
  set allowsContentModifications(value) {
    this._set("allowsContentModifications", value);
  }
  get color() {
    return this._get("color");
  }
  set color(value) {
    this._set("color", value);
  }
  /**
     * _Checks if the calendar supports availability._
     *
     * The following values are supported:
     *
     * *   busy
     * *   free
     * *   tentative
     * *   unavailable
     *
     * Not all calendars support all of these availabilities and some calendars may not support availability at all. Use this function to check if the calendar supports a specific
     * availability.
     * @param availability - Availability to check against.
     * @see https://docs.scriptable.app/calendar/#-supportsavailability
     */
  supportsAvailability(availability) {
    return this._invoke("supportsAvailability", Array.from(arguments));
  }
  /**
     * _Saves calendar._
     *
     * Saves changes to the calendar.
     * @see https://docs.scriptable.app/calendar/#-save
     */
  save() {
    return this._invoke("save", Array.from(arguments));
  }
  /**
     * _Removes calendar._
     *
     * The calendar is removed immediately. This cannot be undone.
     * @see https://docs.scriptable.app/calendar/#-remove
     */
  remove() {
    return this._invoke("remove", Array.from(arguments));
  }
}
class AbsCalendarEvent extends ScriptableObject {
  static type = "CalendarEvent";
  /**
     * _Presents a view for creating a calendar event._
     *
     * The presented view supports editing various attributes of the event, including title, location, dates, recurrence and alerts.
     * @see https://docs.scriptable.app/calendarevent/#presentcreate
     */
  static presentCreate() {
    return this._invokeStatic("presentCreate", Array.from(arguments));
  }
  /**
     * _Events occurring today._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#today
     */
  static today(calendars) {
    return this._invokeStatic("today", Array.from(arguments));
  }
  /**
     * _Events occurring tomorrow._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#tomorrow
     */
  static tomorrow(calendars) {
    return this._invokeStatic("tomorrow", Array.from(arguments));
  }
  /**
     * _Events that occurred yesterday._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#yesterday
     */
  static yesterday(calendars) {
    return this._invokeStatic("yesterday", Array.from(arguments));
  }
  /**
     * _Events that occur this week._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#thisweek
     */
  static thisWeek(calendars) {
    return this._invokeStatic("thisWeek", Array.from(arguments));
  }
  /**
     * _Events that occur next week._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#nextweek
     */
  static nextWeek(calendars) {
    return this._invokeStatic("nextWeek", Array.from(arguments));
  }
  /**
     * _Events that occurred last week._
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#lastweek
     */
  static lastWeek(calendars) {
    return this._invokeStatic("lastWeek", Array.from(arguments));
  }
  /**
     * _Events that occurs between two dates._
     * @param startDate - Start date to fetch events for.
     * @param endDate - End date to fetch events for.
     * @param calendars - Calendars to fetch events for. Defaults to all calendars.
     * @see https://docs.scriptable.app/calendarevent/#between
     */
  static between(startDate, endDate, calendars) {
    return this._invokeStatic("between", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get title() {
    return this._get("title");
  }
  set title(value) {
    this._set("title", value);
  }
  get location() {
    return this._get("location");
  }
  set location(value) {
    this._set("location", value);
  }
  get notes() {
    return this._get("notes");
  }
  set notes(value) {
    this._set("notes", value);
  }
  get startDate() {
    return this._get("startDate");
  }
  set startDate(value) {
    this._set("startDate", value);
  }
  get endDate() {
    return this._get("endDate");
  }
  set endDate(value) {
    this._set("endDate", value);
  }
  get isAllDay() {
    return this._get("isAllDay");
  }
  set isAllDay(value) {
    this._set("isAllDay", value);
  }
  get attendees() {
    return this._get("attendees");
  }
  set attendees(value) {
    this._set("attendees", value);
  }
  get availability() {
    return this._get("availability");
  }
  set availability(value) {
    this._set("availability", value);
  }
  get timeZone() {
    return this._get("timeZone");
  }
  set timeZone(value) {
    this._set("timeZone", value);
  }
  get calendar() {
    return this._get("calendar");
  }
  set calendar(value) {
    this._set("calendar", value);
  }
  /**
     * _Adds a recurrence rule._
     *
     * Recurrence rules specify when the event or reminder should be repeated. See the documentation of RecurrenceRule for more information on creating rules.
     * @param recurrenceRule - Recurrence rule to add to the reminder.
     * @see https://docs.scriptable.app/calendarevent/#-addrecurrencerule
     */
  addRecurrenceRule(recurrenceRule) {
    return this._invoke("addRecurrenceRule", Array.from(arguments));
  }
  /**
     * _Removes all recurrence rules._
     * @see https://docs.scriptable.app/calendarevent/#-removeallrecurrencerules
     */
  removeAllRecurrenceRules() {
    return this._invoke("removeAllRecurrenceRules", Array.from(arguments));
  }
  /**
     * _Saves event._
     *
     * Saves changes to an event, inserting it into the calendar if it is newly created.
     * @see https://docs.scriptable.app/calendarevent/#-save
     */
  save() {
    return this._invoke("save", Array.from(arguments));
  }
  /**
     * _Removes event from calendar._
     * @see https://docs.scriptable.app/calendarevent/#-remove
     */
  remove() {
    return this._invoke("remove", Array.from(arguments));
  }
  /**
     * _Presents a view for editing the calendar event._
     *
     * The presented view supports editing various attributes of the event, including title, location, dates, recurrence and alerts.
     * @see https://docs.scriptable.app/calendarevent/#-presentedit
     */
  presentEdit() {
    return this._invoke("presentEdit", Array.from(arguments));
  }
}
class AbsCallbackURL extends ScriptableObject {
  static type = "CallbackURL";
  /**
     * _Construct CallbackURL._
     *
     * Appends a key/value pair to the base URL as a query parameter. The name and value are automatically encoded. Do not add the x-callback-url paramters, i.e. x-source, x-success,
     * x-error and x-cancel as Scriptable will add those.
     * @param name - Name of the query parameter to add.
     * @param value - Value of the query parameter to add.
     * @see https://docs.scriptable.app/callbackurl/#-addparameter
     */
  addParameter(name, value) {
    return this._invoke("addParameter", Array.from(arguments));
  }
  /**
     * _Opens the callback URL._
     *
     * Opens the target app and waits for the target app to perform the action. The returned promise contains the query parameters supplied by the target app when it invokes the callback.
     * If the action failed in the target app or the action was cancelled, the promise will be rejected. The promise is also rejected if the action times out because the target app did
     * not invoke the callback.
     * @see https://docs.scriptable.app/callbackurl/#-open
     */
  open() {
    return this._invoke("open", Array.from(arguments));
  }
  /**
     * _Creates the callback URL._
     *
     * Creates a callback URL with the specified base URL and query parameters.
     * @see https://docs.scriptable.app/callbackurl/#-geturl
     */
  getURL() {
    return this._invoke("getURL", Array.from(arguments));
  }
}
class AbsColor extends ScriptableObject {
  static type = "Color";
  /**
     * _Constructs a black color._
     * @see https://docs.scriptable.app/color/#black
     */
  static black() {
    return this._invokeStatic("black", Array.from(arguments));
  }
  /**
     * _Constructs a dark gray color._
     * @see https://docs.scriptable.app/color/#darkgray
     */
  static darkGray() {
    return this._invokeStatic("darkGray", Array.from(arguments));
  }
  /**
     * _Constructs a light gray color._
     * @see https://docs.scriptable.app/color/#lightgray
     */
  static lightGray() {
    return this._invokeStatic("lightGray", Array.from(arguments));
  }
  /**
     * _Constructs a white color._
     * @see https://docs.scriptable.app/color/#white
     */
  static white() {
    return this._invokeStatic("white", Array.from(arguments));
  }
  /**
     * _Constructs a gray color._
     * @see https://docs.scriptable.app/color/#gray
     */
  static gray() {
    return this._invokeStatic("gray", Array.from(arguments));
  }
  /**
     * _Constructs a red color._
     * @see https://docs.scriptable.app/color/#red
     */
  static red() {
    return this._invokeStatic("red", Array.from(arguments));
  }
  /**
     * _Constructs a green color._
     * @see https://docs.scriptable.app/color/#green
     */
  static green() {
    return this._invokeStatic("green", Array.from(arguments));
  }
  /**
     * _Constructs a blue color._
     * @see https://docs.scriptable.app/color/#blue
     */
  static blue() {
    return this._invokeStatic("blue", Array.from(arguments));
  }
  /**
     * _Constructs a cyan color._
     * @see https://docs.scriptable.app/color/#cyan
     */
  static cyan() {
    return this._invokeStatic("cyan", Array.from(arguments));
  }
  /**
     * _Constructs a yellow color._
     * @see https://docs.scriptable.app/color/#yellow
     */
  static yellow() {
    return this._invokeStatic("yellow", Array.from(arguments));
  }
  /**
     * _Constructs a magenta color._
     * @see https://docs.scriptable.app/color/#magenta
     */
  static magenta() {
    return this._invokeStatic("magenta", Array.from(arguments));
  }
  /**
     * _Constructs a orange color._
     * @see https://docs.scriptable.app/color/#orange
     */
  static orange() {
    return this._invokeStatic("orange", Array.from(arguments));
  }
  /**
     * _Constructs a purple color._
     * @see https://docs.scriptable.app/color/#purple
     */
  static purple() {
    return this._invokeStatic("purple", Array.from(arguments));
  }
  /**
     * _Constructs a brown color._
     * @see https://docs.scriptable.app/color/#brown
     */
  static brown() {
    return this._invokeStatic("brown", Array.from(arguments));
  }
  /**
     * _Constructs a transparent color._
     * @see https://docs.scriptable.app/color/#clear
     */
  static clear() {
    return this._invokeStatic("clear", Array.from(arguments));
  }
  /**
     * _Creates a dynamic color._
     *
     * The dynamic color will use either its light or dark variant depending on the appearance of the system.
     *
     * Dynamic colors are not supported when used with `DrawContext`.
     * @param lightColor - Color used in light appearance.
     * @param darkColor - Color used in dark appearance.
     * @see https://docs.scriptable.app/color/#dynamic
     */
  static dynamic(lightColor, darkColor) {
    return this._invokeStatic("dynamic", Array.from(arguments));
  }
  get hex() {
    return this._get("hex");
  }
  set hex(value) {
    this._set("hex", value);
  }
  get red() {
    return this._get("red");
  }
  set red(value) {
    this._set("red", value);
  }
  get green() {
    return this._get("green");
  }
  set green(value) {
    this._set("green", value);
  }
  get blue() {
    return this._get("blue");
  }
  set blue(value) {
    this._set("blue", value);
  }
  get alpha() {
    return this._get("alpha");
  }
  set alpha(value) {
    this._set("alpha", value);
  }
}
class AbsContact extends ScriptableObject {
  static type = "Contact";
  /**
     * _Fetches contacts._
     *
     * Fetches the contacts in the specified containers. A contact can be in only one container.
     * @param containers - Containers to fetch contacts from.
     * @see https://docs.scriptable.app/contact/#all
     */
  static all(containers) {
    return this._invokeStatic("all", Array.from(arguments));
  }
  /**
     * _Fetches contacts in groups._
     *
     * Fetches the contacts in the specified contacts groups. A contact may belong to many groups.
     * @param groups - Groups to fetch contacts from.
     * @see https://docs.scriptable.app/contact/#ingroups
     */
  static inGroups(groups) {
    return this._invokeStatic("inGroups", Array.from(arguments));
  }
  /**
     * _Queues a contact to be added._
     *
     * After you have created a contact, you must queue the contact to be added to the address book and invoke `Contact.persistChanges()` to persist the changes to the address book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param contact - Contact to queue to be added.
     * @param containerIdentifier - Optional. Identifier of container to add the contact to. If null is specified, the contact will be added to the default container.
     * @see https://docs.scriptable.app/contact/#add
     */
  static add(contact, containerIdentifier) {
    return this._invokeStatic("add", Array.from(arguments));
  }
  /**
     * _Queues an update to a contact._
     *
     * After you have updated one or more properties on a contact, you must queue the contact to be updated and invoke `Contact.persistChanges()` to persist the changes to the address
     * book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param contact - Contact to queue to be updated.
     * @see https://docs.scriptable.app/contact/#update
     */
  static update(contact) {
    return this._invokeStatic("update", Array.from(arguments));
  }
  /**
     * _Queues a contact to be deleted._
     *
     * To delete a contact, you must queue the contact for deletion and invoke `Contact.persistChanges()` to persist the changes to the address book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param contact - Contact to queue to be deleted.
     * @see https://docs.scriptable.app/contact/#delete
     */
  static delete(contact) {
    return this._invokeStatic("delete", Array.from(arguments));
  }
  /**
     * _Persist queued changes to the address book._
     *
     * Call this function to persist changes queued with `Contact.add()`, `Contact.update()` and `Contact.delete()`.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @see https://docs.scriptable.app/contact/#persistchanges
     */
  static persistChanges() {
    return this._invokeStatic("persistChanges", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get namePrefix() {
    return this._get("namePrefix");
  }
  set namePrefix(value) {
    this._set("namePrefix", value);
  }
  get givenName() {
    return this._get("givenName");
  }
  set givenName(value) {
    this._set("givenName", value);
  }
  get middleName() {
    return this._get("middleName");
  }
  set middleName(value) {
    this._set("middleName", value);
  }
  get familyName() {
    return this._get("familyName");
  }
  set familyName(value) {
    this._set("familyName", value);
  }
  get nickname() {
    return this._get("nickname");
  }
  set nickname(value) {
    this._set("nickname", value);
  }
  get birthday() {
    return this._get("birthday");
  }
  set birthday(value) {
    this._set("birthday", value);
  }
  get image() {
    return this._get("image");
  }
  set image(value) {
    this._set("image", value);
  }
  get emailAddresses() {
    return this._get("emailAddresses");
  }
  set emailAddresses(value) {
    this._set("emailAddresses", value);
  }
  get phoneNumbers() {
    return this._get("phoneNumbers");
  }
  set phoneNumbers(value) {
    this._set("phoneNumbers", value);
  }
  get postalAddresses() {
    return this._get("postalAddresses");
  }
  set postalAddresses(value) {
    this._set("postalAddresses", value);
  }
  get socialProfiles() {
    return this._get("socialProfiles");
  }
  set socialProfiles(value) {
    this._set("socialProfiles", value);
  }
  get note() {
    return this._get("note");
  }
  set note(value) {
    this._set("note", value);
  }
  get urlAddresses() {
    return this._get("urlAddresses");
  }
  set urlAddresses(value) {
    this._set("urlAddresses", value);
  }
  get dates() {
    return this._get("dates");
  }
  set dates(value) {
    this._set("dates", value);
  }
  get organizationName() {
    return this._get("organizationName");
  }
  set organizationName(value) {
    this._set("organizationName", value);
  }
  get departmentName() {
    return this._get("departmentName");
  }
  set departmentName(value) {
    this._set("departmentName", value);
  }
  get jobTitle() {
    return this._get("jobTitle");
  }
  set jobTitle(value) {
    this._set("jobTitle", value);
  }
  get isNamePrefixAvailable() {
    return this._get("isNamePrefixAvailable");
  }
  set isNamePrefixAvailable(value) {
    this._set("isNamePrefixAvailable", value);
  }
  get isGiveNameAvailable() {
    return this._get("isGiveNameAvailable");
  }
  set isGiveNameAvailable(value) {
    this._set("isGiveNameAvailable", value);
  }
  get isMiddleNameAvailable() {
    return this._get("isMiddleNameAvailable");
  }
  set isMiddleNameAvailable(value) {
    this._set("isMiddleNameAvailable", value);
  }
  get isFamilyNameAvailable() {
    return this._get("isFamilyNameAvailable");
  }
  set isFamilyNameAvailable(value) {
    this._set("isFamilyNameAvailable", value);
  }
  get isNicknameAvailable() {
    return this._get("isNicknameAvailable");
  }
  set isNicknameAvailable(value) {
    this._set("isNicknameAvailable", value);
  }
  get isBirthdayAvailable() {
    return this._get("isBirthdayAvailable");
  }
  set isBirthdayAvailable(value) {
    this._set("isBirthdayAvailable", value);
  }
  get isEmailAddressesAvailable() {
    return this._get("isEmailAddressesAvailable");
  }
  set isEmailAddressesAvailable(value) {
    this._set("isEmailAddressesAvailable", value);
  }
  get isPhoneNumbersAvailable() {
    return this._get("isPhoneNumbersAvailable");
  }
  set isPhoneNumbersAvailable(value) {
    this._set("isPhoneNumbersAvailable", value);
  }
  get isPostalAddressesAvailable() {
    return this._get("isPostalAddressesAvailable");
  }
  set isPostalAddressesAvailable(value) {
    this._set("isPostalAddressesAvailable", value);
  }
  get isSocialProfilesAvailable() {
    return this._get("isSocialProfilesAvailable");
  }
  set isSocialProfilesAvailable(value) {
    this._set("isSocialProfilesAvailable", value);
  }
  get isImageAvailable() {
    return this._get("isImageAvailable");
  }
  set isImageAvailable(value) {
    this._set("isImageAvailable", value);
  }
  get isNoteAvailable() {
    return this._get("isNoteAvailable");
  }
  set isNoteAvailable(value) {
    this._set("isNoteAvailable", value);
  }
  get isURLAddressesAvailable() {
    return this._get("isURLAddressesAvailable");
  }
  set isURLAddressesAvailable(value) {
    this._set("isURLAddressesAvailable", value);
  }
  get isOrganizationNameAvailable() {
    return this._get("isOrganizationNameAvailable");
  }
  set isOrganizationNameAvailable(value) {
    this._set("isOrganizationNameAvailable", value);
  }
  get isDepartmentNameAvailable() {
    return this._get("isDepartmentNameAvailable");
  }
  set isDepartmentNameAvailable(value) {
    this._set("isDepartmentNameAvailable", value);
  }
  get isJobTitleAvailable() {
    return this._get("isJobTitleAvailable");
  }
  set isJobTitleAvailable(value) {
    this._set("isJobTitleAvailable", value);
  }
  get isDatesAvailable() {
    return this._get("isDatesAvailable");
  }
  set isDatesAvailable(value) {
    this._set("isDatesAvailable", value);
  }
}
class AbsContactsContainer extends ScriptableObject {
  static type = "ContactsContainer";
  /**
     * _Fetches default contacts container._
     * @see https://docs.scriptable.app/contactscontainer/#default
     */
  static default() {
    return this._invokeStatic("default", Array.from(arguments));
  }
  /**
     * _Fetches all contacts containers._
     * @see https://docs.scriptable.app/contactscontainer/#all
     */
  static all() {
    return this._invokeStatic("all", Array.from(arguments));
  }
  /**
     * _Fetches a contacts container._
     * @param identifier - Identifier of the contacts container to fetch.
     * @see https://docs.scriptable.app/contactscontainer/#withidentifier
     */
  static withIdentifier(identifier) {
    return this._invokeStatic("withIdentifier", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get name() {
    return this._get("name");
  }
  set name(value) {
    this._set("name", value);
  }
}
class AbsContactsGroup extends ScriptableObject {
  static type = "ContactsGroup";
  /**
     * _Fetches contacts groups._
     *
     * Fetches the contacts groups in the specified containers. A group can be in only one container.
     * @param containers - Container to fetch contacts groups from.
     * @see https://docs.scriptable.app/contactsgroup/#all
     */
  static all(containers) {
    return this._invokeStatic("all", Array.from(arguments));
  }
  /**
     * _Queues a contacts group to be added._
     *
     * After you have created a group, you must queue the group to be added to the address book and invoke `Contact.persistChanges()` to persist the changes to the address book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param group - Contacts group to queue to be added.
     * @param containerIdentifier - Optional. Identifier of container to add the contacts group to. If null is specified, the group will be added to the default container.
     * @see https://docs.scriptable.app/contactsgroup/#add
     */
  static add(group, containerIdentifier) {
    return this._invokeStatic("add", Array.from(arguments));
  }
  /**
     * _Queues an update to a contacts group._
     *
     * After you have updated one or more properties on a contacts group, you must queue the group to be updated and invoke `Contact.persistChanges()` to persist the changes to the
     * address book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param group - Contacts group to queue to be updated.
     * @see https://docs.scriptable.app/contactsgroup/#update
     */
  static update(group) {
    return this._invokeStatic("update", Array.from(arguments));
  }
  /**
     * _Queues a contacts group to be deleted._
     *
     * To delete a contacts group, you must queue the group for deletion and invoke `Contact.persistChanges()` to persist the changes to the address book.
     *
     * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
     * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
     * @param group - Contacts group to queue to be deleted.
     * @see https://docs.scriptable.app/contactsgroup/#delete
     */
  static delete(group) {
    return this._invokeStatic("delete", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get name() {
    return this._get("name");
  }
  set name(value) {
    this._set("name", value);
  }
  /**
     * _Adds a contact to the group._
     *
     * In order to persist the change, you should call `Contact.persistChanges()`. It is important that the contact is added to the address book. To add the contact to the address book,
     * you should queue it for insertion using `Contact.add()` before persisting the changes.
     * @param contact - Contact to add to the group.
     * @see https://docs.scriptable.app/contactsgroup/#-addmember
     */
  addMember(contact) {
    return this._invoke("addMember", Array.from(arguments));
  }
  /**
     * _Removes a contact from the group._
     *
     * In order to persist the change, you should call `Contact.persistChanges()`. It is important that the contact is added to the address book. To add the contact to the address book,
     * you should queue it for insertion using `Contact.add()` before persisting the changes.
     * @param contact - Contact to add to the group.
     * @see https://docs.scriptable.app/contactsgroup/#-removemember
     */
  removeMember(contact) {
    return this._invoke("removeMember", Array.from(arguments));
  }
}
class AbsData extends ScriptableObject {
  static type = "Data";
  /**
     * _Creates data from string._
     *
     * The provided string is assumed to be UTF8 encoded. If the string is not UTF8 encoded, the function will return null.
     * @param string - String to create data from.
     * @see https://docs.scriptable.app/data/#fromstring
     */
  static fromString(string) {
    return this._invokeStatic("fromString", Array.from(arguments));
  }
  /**
     * _Reads data from file path._
     *
     * Reads the raw data of the file at the specified file path.
     * @param filePath - Path of file to read data from.
     * @see https://docs.scriptable.app/data/#fromfile
     */
  static fromFile(filePath) {
    return this._invokeStatic("fromFile", Array.from(arguments));
  }
  /**
     * _Creates data from base64 encoded string._
     *
     * The supplied string must be base64 encoded otherwise the function will return null.
     * @param base64String - Base64 encoded string to create data from.
     * @see https://docs.scriptable.app/data/#frombase64string
     */
  static fromBase64String(base64String) {
    return this._invokeStatic("fromBase64String", Array.from(arguments));
  }
  /**
     * _Creates data from JPEG image._
     * @param image - JPEG image to convert to data.
     * @see https://docs.scriptable.app/data/#fromjpeg
     */
  static fromJPEG(image) {
    return this._invokeStatic("fromJPEG", Array.from(arguments));
  }
  /**
     * _Creates data from PNG image._
     * @param image - PNG image to convert to data.
     * @see https://docs.scriptable.app/data/#frompng
     */
  static fromPNG(image) {
    return this._invokeStatic("fromPNG", Array.from(arguments));
  }
  /**
     * _Creates data from an array of bytes._
     * @param bytes - Array of bytes to convert to data.
     * @see https://docs.scriptable.app/data/#frombytes
     */
  static fromBytes(bytes) {
    return this._invokeStatic("fromBytes", Array.from(arguments));
  }
  /**
     * _Creates a string from the data._
     *
     * The data is assumed to represent a UTF8 encoded string. If the string is not UTF8 encoded string, the function will return null.
     * @see https://docs.scriptable.app/data/#-torawstring
     */
  toRawString() {
    return this._invoke("toRawString", Array.from(arguments));
  }
  /**
     * _Creates a base64 encoded string._
     *
     * Creates a base64 encoded string from the data.
     * @see https://docs.scriptable.app/data/#-tobase64string
     */
  toBase64String() {
    return this._invoke("toBase64String", Array.from(arguments));
  }
  /**
     * _Gets bytes from data._
     * @see https://docs.scriptable.app/data/#-getbytes
     */
  getBytes() {
    return this._invoke("getBytes", Array.from(arguments));
  }
}
class AbsDateFormatter extends ScriptableObject {
  static type = "DateFormatter";
  get dateFormat() {
    return this._get("dateFormat");
  }
  set dateFormat(value) {
    this._set("dateFormat", value);
  }
  get locale() {
    return this._get("locale");
  }
  set locale(value) {
    this._set("locale", value);
  }
  /**
     * _Creates a string from a date._
     * @param date - The date to convert to a string.
     * @see https://docs.scriptable.app/dateformatter/#-string
     */
  string(date) {
    return this._invoke("string", Array.from(arguments));
  }
  /**
     * _Creates a date from a string._
     *
     * Uses the date formatters configuration to parse the string into a date. If the string cannot be parsed with the date foramtters configuration, the function will return null.
     * @param str - The string to parse into a date.
     * @see https://docs.scriptable.app/dateformatter/#-date
     */
  date(str) {
    return this._invoke("date", Array.from(arguments));
  }
  /**
     * _Use no style for the date._
     *
     * This will remove the date from the formatted string.
     * @see https://docs.scriptable.app/dateformatter/#-usenodatestyle
     */
  useNoDateStyle() {
    return this._invoke("useNoDateStyle", Array.from(arguments));
  }
  /**
     * _Use a short style for the date._
     *
     * Dates with a short style are typically numeric only e.g. "08/23/19".
     * @see https://docs.scriptable.app/dateformatter/#-useshortdatestyle
     */
  useShortDateStyle() {
    return this._invoke("useShortDateStyle", Array.from(arguments));
  }
  /**
     * _Use a medium style for the date._
     *
     * Dates with a medium style usually includes abbreviations, e.g. "Aug 23, 2019".
     * @see https://docs.scriptable.app/dateformatter/#-usemediumdatestyle
     */
  useMediumDateStyle() {
    return this._invoke("useMediumDateStyle", Array.from(arguments));
  }
  /**
     * _Use a long style for the date._
     *
     * Dates with a long style usually includes a full text, e.g. "August 23, 2019".
     * @see https://docs.scriptable.app/dateformatter/#-uselongdatestyle
     */
  useLongDateStyle() {
    return this._invoke("useLongDateStyle", Array.from(arguments));
  }
  /**
     * _Use a full style for the date._
     *
     * Dates with a full style includes all details, e.g. "Friday, August 23, 2019 AD".
     * @see https://docs.scriptable.app/dateformatter/#-usefulldatestyle
     */
  useFullDateStyle() {
    return this._invoke("useFullDateStyle", Array.from(arguments));
  }
  /**
     * _Use no style for the time._
     *
     * This will remove the time from the formatted string.
     * @see https://docs.scriptable.app/dateformatter/#-usenotimestyle
     */
  useNoTimeStyle() {
    return this._invoke("useNoTimeStyle", Array.from(arguments));
  }
  /**
     * _Use a short style for the time._
     *
     * Times with a short style are typically numeric only but also includes the period for 12-hour clocks, e.g. "7:17 PM".
     * @see https://docs.scriptable.app/dateformatter/#-useshorttimestyle
     */
  useShortTimeStyle() {
    return this._invoke("useShortTimeStyle", Array.from(arguments));
  }
  /**
     * _Use a short style for the time._
     *
     * Times with a medium style usually includes abbreviations, e.g. "7:16:42 PM".
     * @see https://docs.scriptable.app/dateformatter/#-usemediumtimestyle
     */
  useMediumTimeStyle() {
    return this._invoke("useMediumTimeStyle", Array.from(arguments));
  }
  /**
     * _Use a long style for the time._
     *
     * Times with a long style usually includes a full text, e.g. "7:16:42 PM PST".
     * @see https://docs.scriptable.app/dateformatter/#-uselongtimestyle
     */
  useLongTimeStyle() {
    return this._invoke("useLongTimeStyle", Array.from(arguments));
  }
  /**
     * _Use a full style for the time._
     *
     * Times with a full style includes all details, e.g. "7:16:42 PM Pacific Standard Time".
     * @see https://docs.scriptable.app/dateformatter/#-usefulltimestyle
     */
  useFullTimeStyle() {
    return this._invoke("useFullTimeStyle", Array.from(arguments));
  }
}
class AbsDatePicker extends ScriptableObject {
  static type = "DatePicker";
  get minimumDate() {
    return this._get("minimumDate");
  }
  set minimumDate(value) {
    this._set("minimumDate", value);
  }
  get maximumDate() {
    return this._get("maximumDate");
  }
  set maximumDate(value) {
    this._set("maximumDate", value);
  }
  get countdownDuration() {
    return this._get("countdownDuration");
  }
  set countdownDuration(value) {
    this._set("countdownDuration", value);
  }
  get minuteInterval() {
    return this._get("minuteInterval");
  }
  set minuteInterval(value) {
    this._set("minuteInterval", value);
  }
  get initialDate() {
    return this._get("initialDate");
  }
  set initialDate(value) {
    this._set("initialDate", value);
  }
  /**
     * _Presents the date picker displaying hours and minutes._
     *
     * Use the method to pick a time. The date picker will display hours and minutes and, depending on the locale of the device, an AM/PM designation.
     *
     * The returned date will be the current date with the hour and minute set to the selected values. Use the `initialDate` property to set the initially selected date.
     * @see https://docs.scriptable.app/datepicker/#-picktime
     */
  pickTime() {
    return this._invoke("pickTime", Array.from(arguments));
  }
  /**
     * _Presents the date picker displaying day, month and year._
     *
     * Use the method to pick a date. The date picker will display the day, month and year. Use the `initialDate` property to set the initially selected date.
     * @see https://docs.scriptable.app/datepicker/#-pickdate
     */
  pickDate() {
    return this._invoke("pickDate", Array.from(arguments));
  }
  /**
     * _Presents the date picker displaying date and time._
     *
     * Use the method to pick a date and a time. The date picker will display the day, month, year, hour, minutes and, depending on the locale of the device, an AM/PM designation. Use the
     * `initialDate` property to set the initially selected date.
     * @see https://docs.scriptable.app/datepicker/#-pickdateandtime
     */
  pickDateAndTime() {
    return this._invoke("pickDateAndTime", Array.from(arguments));
  }
  /**
     * _Presents the date picker for selecting the duration of a countdown._
     *
     * Use the method to pick the duration of a countdown, e.g. a timer. The date picker will display hours and minutes. Use the `countdownDuration` property to set the initially selected
     * duration.
     * @see https://docs.scriptable.app/datepicker/#-pickcountdownduration
     */
  pickCountdownDuration() {
    return this._invoke("pickCountdownDuration", Array.from(arguments));
  }
}
class AbsDrawContext extends ScriptableObject {
  static type = "DrawContext";
  get size() {
    return this._get("size");
  }
  set size(value) {
    this._set("size", value);
  }
  get respectScreenScale() {
    return this._get("respectScreenScale");
  }
  set respectScreenScale(value) {
    this._set("respectScreenScale", value);
  }
  get opaque() {
    return this._get("opaque");
  }
  set opaque(value) {
    this._set("opaque", value);
  }
  /**
     * _Retrieves the image._
     *
     * Call this to retrieve the image you have drawn to the context.
     * @see https://docs.scriptable.app/drawcontext/#-getimage
     */
  getImage() {
    return this._invoke("getImage", Array.from(arguments));
  }
  /**
     * _Draws an image in the specified rect._
     *
     * Draws the image in the rectangle. The image will be scaled to fit within the rectangle.
     * @param image - Image to draw.
     * @param rect - Rectangle to draw the image in.
     * @see https://docs.scriptable.app/drawcontext/#-drawimageinrect
     */
  drawImageInRect(image, rect) {
    return this._invoke("drawImageInRect", Array.from(arguments));
  }
  /**
     * _Draws an image at the specified point._
     *
     * Draws the image at the point. The top-left corner of the image will be drawn at the specified point.
     * @param image - Image to draw.
     * @param point - Point at which to draw top-left corner of the image.
     * @see https://docs.scriptable.app/drawcontext/#-drawimageatpoint
     */
  drawImageAtPoint(image, point) {
    return this._invoke("drawImageAtPoint", Array.from(arguments));
  }
  /**
     * _Sets the fill color._
     *
     * Sets the fill color to be used when performing a fill operation. Any fill operation performed afterwards will fill with the specified color until another call to setFillColor is
     * made.
     * @param color - Color to set for filling.
     * @see https://docs.scriptable.app/drawcontext/#-setfillcolor
     */
  setFillColor(color) {
    return this._invoke("setFillColor", Array.from(arguments));
  }
  /**
     * _Sets the stroke color._
     *
     * Sets the stroke color to be used when performing a stroke operation. Any stroke operation performed afterwards will stroke with the specified color until another call to
     * setStrokeColor is made.
     * @param color - Color to set for stroking.
     * @see https://docs.scriptable.app/drawcontext/#-setstrokecolor
     */
  setStrokeColor(color) {
    return this._invoke("setStrokeColor", Array.from(arguments));
  }
  /**
     * _Sets the line width for stroking._
     *
     * Sets the line width to be used when performing a stroke operation.
     * @param width - Line width to use for stroking.
     * @see https://docs.scriptable.app/drawcontext/#-setlinewidth
     */
  setLineWidth(width) {
    return this._invoke("setLineWidth", Array.from(arguments));
  }
  /**
     * _Fills a rectangle._
     *
     * Fills the rectangle with the color set when calling setFillColor.
     * @param rect - Rectangle to fill.
     * @see https://docs.scriptable.app/drawcontext/#-fill
     */
  fill(rect) {
    return this._invoke("fill", Array.from(arguments));
  }
  /**
     * _Fills a rectangle._
     *
     * Fills the rectangle with the color set when calling setFillColor.
     * @param rect - Rectangle to fill.
     * @see https://docs.scriptable.app/drawcontext/#-fillrect
     */
  fillRect(rect) {
    return this._invoke("fillRect", Array.from(arguments));
  }
  /**
     * _Fills an ellipse._
     *
     * Fills the ellipse that fits within the supplied rectangle with the color set when calling setFillColor.
     * @param rect - Rectangle incapsulating the ellipse to fill.
     * @see https://docs.scriptable.app/drawcontext/#-fillellipse
     */
  fillEllipse(rect) {
    return this._invoke("fillEllipse", Array.from(arguments));
  }
  /**
     * _Strokes a rectangle._
     *
     * Draws a line around the rectangle using the color set when calling setStrokeColor. The line will have the width set when calling setLineWidth.
     * @param rect - Rectangle to stroke.
     * @see https://docs.scriptable.app/drawcontext/#-stroke
     */
  stroke(rect) {
    return this._invoke("stroke", Array.from(arguments));
  }
  /**
     * _Strokes a rectangle._
     *
     * Draws a line around the rectangle using the color set when calling setStrokeColor. The line will have the width set when calling setLineWidth.
     * @param rect - Rectangle to stroke.
     * @see https://docs.scriptable.app/drawcontext/#-strokerect
     */
  strokeRect(rect) {
    return this._invoke("strokeRect", Array.from(arguments));
  }
  /**
     * _Strokes an ellipse._
     *
     * Draws a line around the ellipse that fits within the supplied rectangle. The line will have the color set when calling setStrokeColor and the width set when calling setLineWidth.
     * @param rect - Rectangle incapsulating the ellipse to stroke.
     * @see https://docs.scriptable.app/drawcontext/#-strokeellipse
     */
  strokeEllipse(rect) {
    return this._invoke("strokeEllipse", Array.from(arguments));
  }
  /**
     * _Adds a path to the context._
     *
     * After adding a path to the context, the path can be stroked or filled by calling strokePath and fillPath. Note that only the path that was added latest will be affected by calls to
     * strokePath and fillPath.
     * @param path - Path to add to the context.
     * @see https://docs.scriptable.app/drawcontext/#-addpath
     */
  addPath(path) {
    return this._invoke("addPath", Array.from(arguments));
  }
  /**
     * _Strokes the path that was added the latest._
     *
     * The path that was added the latest to the context is stroked with the color set using setStrokeColor and the line width set using setLineWidth.
     * @see https://docs.scriptable.app/drawcontext/#-strokepath
     */
  strokePath() {
    return this._invoke("strokePath", Array.from(arguments));
  }
  /**
     * _Fills the path that was added the latest._
     *
     * The path that was latest added to the context is filled with the color set using setFillColor.
     * @see https://docs.scriptable.app/drawcontext/#-fillpath
     */
  fillPath() {
    return this._invoke("fillPath", Array.from(arguments));
  }
  /**
     * _Draws text at a position._
     *
     * Call this to draw a text string to the context. The top-left of the text will be drawn at the specified position.
     * @param text - Text to draw.
     * @param pos - Position to draw the top-left of the text.
     * @see https://docs.scriptable.app/drawcontext/#-drawtext
     */
  drawText(text, pos) {
    return this._invoke("drawText", Array.from(arguments));
  }
  /**
     * _Draws text in a rectangle._
     *
     * Call this to draw a text string in a rectangle. Specify how the text should be aligned within the rectangle by calling setTextAlignedLeft, setTextAlignedCenter or
     * setTextAlignedRight before drawing the text.
     * @param text - Text to draw.
     * @param rect - Rectangle to draw text in.
     * @see https://docs.scriptable.app/drawcontext/#-drawtextinrect
     */
  drawTextInRect(text, rect) {
    return this._invoke("drawTextInRect", Array.from(arguments));
  }
  /**
     * _Sets the font to use when drawing text._
     *
     * Sets the font to be used when drawing texts to the context.
     * @param font - Font to use when drawing text.
     * @see https://docs.scriptable.app/drawcontext/#-setfont
     */
  setFont(font) {
    return this._invoke("setFont", Array.from(arguments));
  }
  /**
     * _Sets the text color used when drawing text._
     *
     * Sets the text color to be used when drawing text strings to the context.
     * @param color - Color to use when drawing text.
     * @see https://docs.scriptable.app/drawcontext/#-settextcolor
     */
  setTextColor(color) {
    return this._invoke("setTextColor", Array.from(arguments));
  }
  /**
     * _Specifies that texts should be left aligned._
     *
     * Sets text alignment to left. Texts drawn after calling this will be left aligned inside the provided rectangle.
     * @see https://docs.scriptable.app/drawcontext/#-settextalignedleft
     */
  setTextAlignedLeft() {
    return this._invoke("setTextAlignedLeft", Array.from(arguments));
  }
  /**
     * _Specifies that texts should be center aligned._
     *
     * Sets text alignment to center. Texts drawn after calling this will be center aligned inside the provided rectangle.
     * @see https://docs.scriptable.app/drawcontext/#-settextalignedcenter
     */
  setTextAlignedCenter() {
    return this._invoke("setTextAlignedCenter", Array.from(arguments));
  }
  /**
     * _Specifies that texts should be right aligned._
     *
     * Sets text alignment to right. Texts drawn after calling this will be right aligned inside the provided rectangle.
     * @see https://docs.scriptable.app/drawcontext/#-settextalignedright
     */
  setTextAlignedRight() {
    return this._invoke("setTextAlignedRight", Array.from(arguments));
  }
}
class AbsFileManager extends ScriptableObject {
  static type = "FileManager";
  /**
     * _Creates a local FileManager._
     *
     * Creates a file manager for operating with files stored locally.
     * @see https://docs.scriptable.app/filemanager/#local
     */
  static local() {
    return this._invokeStatic("local", Array.from(arguments));
  }
  /**
     * _Creates an iCloud FileManager._
     *
     * Creates a file manager for operating with files stored in iCloud. iCloud must be enabled on the device in order to use this.
     * @see https://docs.scriptable.app/filemanager/#icloud
     */
  static iCloud() {
    return this._invokeStatic("iCloud", Array.from(arguments));
  }
  /**
     * _Read contents of a file as data._
     *
     * Reads the contents of the file specified by the file path as raw data. To read the file as a string see `readString(filePath)` and to read it as an image see `readImage(filePath)`.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of the file to read.
     * @see https://docs.scriptable.app/filemanager/#-read
     */
  read(filePath) {
    return this._invoke("read", Array.from(arguments));
  }
  /**
     * _Read contents of a file as string._
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of the file to read.
     * @see https://docs.scriptable.app/filemanager/#-readstring
     */
  readString(filePath) {
    return this._invoke("readString", Array.from(arguments));
  }
  /**
     * _Read contents of a file as an image._
     *
     * Reads the contents of the file specified by the file path and converts it to an image.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of the file to read.
     * @see https://docs.scriptable.app/filemanager/#-readimage
     */
  readImage(filePath) {
    return this._invoke("readImage", Array.from(arguments));
  }
  /**
     * _Write data to a file._
     * @param filePath - Path of file to write to.
     * @param content - Data to write to disk.
     * @see https://docs.scriptable.app/filemanager/#-write
     */
  write(filePath, content) {
    return this._invoke("write", Array.from(arguments));
  }
  /**
     * _Write a string to a file._
     *
     * Writes the content to the specified file path on disk. If the file does not already exist, it will be created. If the file already exists the contents of the file will be
     * overwritten with the new content.
     * @param filePath - Path of file to write to.
     * @param content - Content to write to disk.
     * @see https://docs.scriptable.app/filemanager/#-writestring
     */
  writeString(filePath, content) {
    return this._invoke("writeString", Array.from(arguments));
  }
  /**
     * _Write an image to a file._
     *
     * Writes the image to the specified file path on disk. If the file does not already exist, it will be created. If the file already exists the contents of the file will be overwritten
     * with the new content.
     * @param filePath - Path of file to write to.
     * @param image - Image to write to disk.
     * @see https://docs.scriptable.app/filemanager/#-writeimage
     */
  writeImage(filePath, image) {
    return this._invoke("writeImage", Array.from(arguments));
  }
  /**
     * _Removes a file._
     *
     * Removes the file at the specified path. Use with caution. Removed files cannot be restored.
     * @param filePath - Path of file to remove.
     * @see https://docs.scriptable.app/filemanager/#-remove
     */
  remove(filePath) {
    return this._invoke("remove", Array.from(arguments));
  }
  /**
     * _Moves a file._
     *
     * Moves the file from the source path to the destination path. Caution: This operation will replace any existing file at the the destination.
     * @param sourceFilePath - Path of the file to move.
     * @param destinationFilePath - Path to move the file to.
     * @see https://docs.scriptable.app/filemanager/#-move
     */
  move(sourceFilePath, destinationFilePath) {
    return this._invoke("move", Array.from(arguments));
  }
  /**
     * _Copies a file._
     *
     * Copies the file from the source path to the destination path. If a file already exists at the destination file path, the operation will fail and the file will not be copied.
     * @param sourceFilePath - Path of the file to copy.
     * @param destinationFilePath - Path to copy the file to.
     * @see https://docs.scriptable.app/filemanager/#-copy
     */
  copy(sourceFilePath, destinationFilePath) {
    return this._invoke("copy", Array.from(arguments));
  }
  /**
     * _Checks if the file exists._
     *
     * Checks if the file exists at the specified file path. Checking this before moving or copying to a destination can be a good idea as those operations will replace any existing file
     * at the destination file path.
     * @param filePath - File path to examine.
     * @see https://docs.scriptable.app/filemanager/#-fileexists
     */
  fileExists(filePath) {
    return this._invoke("fileExists", Array.from(arguments));
  }
  /**
     * _Checks if a path points to a directory._
     * @param path - Path to examine.
     * @see https://docs.scriptable.app/filemanager/#-isdirectory
     */
  isDirectory(path) {
    return this._invoke("isDirectory", Array.from(arguments));
  }
  /**
     * _Creates a directory at the specified path._
     *
     * You can optionally create all intermediate directories.
     * @param path - Path of directory to create.
     * @param intermediateDirectories - Whether to create all intermediate directories. Defaults to false.
     * @see https://docs.scriptable.app/filemanager/#-createdirectory
     */
  createDirectory(path, intermediateDirectories) {
    return this._invoke("createDirectory", Array.from(arguments));
  }
  /**
     * _Path of temporary directory._
     *
     * Used to retrieve the path of a temporary directory on disk. Data persisted in a temporary directory will generally live shorter than data persisted in the cache directory.
     *
     * The operating system may at any time delete files stored in this directory and therefore you should not rely on it for long time storage. If you need long time storage, see
     * documentsDirectory() or libraryDirectory(). This directory is not shared between the app, the action extension and Siri.
     * @see https://docs.scriptable.app/filemanager/#-temporarydirectory
     */
  temporaryDirectory() {
    return this._invoke("temporaryDirectory", Array.from(arguments));
  }
  /**
     * _Path of cache directory._
     *
     * Used to retrieve the path of a cache directory on disk. The operating system may at any time delete files stored in this directory and therefore you should not rely on it for long
     * time storage.
     *
     * Data persisted in the cache directory will generally live longer than data persisted in a temporary directory.
     *
     * If you need long time storage, see documentsDirectory() or libraryDirectory(). This directory is not shared between the app, the action extension and Siri.
     * @see https://docs.scriptable.app/filemanager/#-cachedirectory
     */
  cacheDirectory() {
    return this._invoke("cacheDirectory", Array.from(arguments));
  }
  /**
     * _Path of documents directory._
     *
     * Used to retrieve the path to the documents directory. Your scripts are stored in this directory. If you have iCloud enabled, your scripts will be stored in the documents directory
     * in iCloud otherwise they will be stored in the local documents directory. The directory can be used for long time storage. Documents stored in this directory can be accessed using
     * the Files app. Files stored in the local documents directory will not appear in the Files app.
     * @see https://docs.scriptable.app/filemanager/#-documentsdirectory
     */
  documentsDirectory() {
    return this._invoke("documentsDirectory", Array.from(arguments));
  }
  /**
     * _Path of library directory._
     *
     * Used to retrieve the path to the library directory. The directory can be used for long time storage. Documents stored in this directory cannot be accessed using the Files app.
     * @see https://docs.scriptable.app/filemanager/#-librarydirectory
     */
  libraryDirectory() {
    return this._invoke("libraryDirectory", Array.from(arguments));
  }
  /**
     * _Joins two path components._
     *
     * Joins two paths to created one path. For example to join the path to a directory with the name of a file. This is the suggested approach for creating new file paths passed to the
     * read and write functions of a FileManager.
     * @param lhsPath - Left-hand side part of the new path.
     * @param rhsPath - Right-hand side part of the new path.
     * @see https://docs.scriptable.app/filemanager/#-joinpath
     */
  joinPath(lhsPath, rhsPath) {
    return this._invoke("joinPath", Array.from(arguments));
  }
  /**
     * _Reads all tags from a file._
     *
     * The tags are read from the file at the specified path. Tags can either be read, added and removed using the Files app by using the APIs provided by a FileManager.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to read tags from.
     * @see https://docs.scriptable.app/filemanager/#-alltags
     */
  allTags(filePath) {
    return this._invoke("allTags", Array.from(arguments));
  }
  /**
     * _Adds a tag to a file._
     *
     * A tag can only be added to a file once. It is not possible to specify a color for the tag. You can create the tags using the Files app to specify the color and then add them to
     * files afterwards using the FileManager API.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to add the tag to.
     * @param tag - Tag to add. This can be an existing tag or a new tag.
     * @see https://docs.scriptable.app/filemanager/#-addtag
     */
  addTag(filePath, tag) {
    return this._invoke("addTag", Array.from(arguments));
  }
  /**
     * _Removes a tag from a file._
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to remove the tag from.
     * @param tag - Tag to remove.
     * @see https://docs.scriptable.app/filemanager/#-removetag
     */
  removeTag(filePath, tag) {
    return this._invoke("removeTag", Array.from(arguments));
  }
  /**
     * _Reads an extended attribute from a file._
     *
     * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
     *
     * The function will return `null` if the attribute does not exist.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to read extended attribute from.
     * @param name - Name of the extended attribute to read.
     * @see https://docs.scriptable.app/filemanager/#-readextendedattribute
     */
  readExtendedAttribute(filePath, name) {
    return this._invoke("readExtendedAttribute", Array.from(arguments));
  }
  /**
     * _Writes an extended attribute to a file._
     *
     * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to add an extended attribute to.
     * @param value - Value of the extended attribute.
     * @param name - Name of the extended attribute. This is used to retrieve the value at a later point.
     * @see https://docs.scriptable.app/filemanager/#-writeextendedattribute
     */
  writeExtendedAttribute(filePath, value, name) {
    return this._invoke("writeExtendedAttribute", Array.from(arguments));
  }
  /**
     * _Removes an extended attribute from a file._
     *
     * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
     *
     * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
     * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
     * @param filePath - Path of file to add an extended attribute to.
     * @param name - Name of the extended attribute to remove.
     * @see https://docs.scriptable.app/filemanager/#-removeextendedattribute
     */
  removeExtendedAttribute(filePath, name) {
    return this._invoke("removeExtendedAttribute", Array.from(arguments));
  }
  /**
     * _Reads all extended attributes on a file._
     *
     * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
     * @param filePath - Path of file to read extended attributes from.
     * @see https://docs.scriptable.app/filemanager/#-allextendedattributes
     */
  allExtendedAttributes(filePath) {
    return this._invoke("allExtendedAttributes", Array.from(arguments));
  }
  /**
     * _Gets the UTI of the specified file._
     *
     * The Uniform Type Identifier is a string that identifies the type of file.
     * @param filePath - Path of file to get UTI of.
     * @see https://docs.scriptable.app/filemanager/#-getuti
     */
  getUTI(filePath) {
    return this._invoke("getUTI", Array.from(arguments));
  }
  /**
     * _Lists content of directory._
     *
     * Lists all the contents in the specified directory. The returned array contains filenames of all files and directories in the specified directory.
     * @param directoryPath - Path to directory.
     * @see https://docs.scriptable.app/filemanager/#-listcontents
     */
  listContents(directoryPath) {
    return this._invoke("listContents", Array.from(arguments));
  }
  /**
     * _Get name of a file._
     *
     * Takes a file path and returns the name of the file. Also supports getting the name of a directory. The returned file name optionally includes the extension of the file.
     * @param filePath - path of file to get name of.
     * @param includeFileExtension - Whether or not the file extension should be included. Defaults to false.
     * @see https://docs.scriptable.app/filemanager/#-filename
     */
  fileName(filePath, includeFileExtension) {
    return this._invoke("fileName", Array.from(arguments));
  }
  /**
     * _Get extension of a file._
     *
     * Takes a file path and returns the extension of the file, e.g. ".jpg" or ".js". Returns en empty string for directories.
     * @param filePath - Path of file to get extension from.
     * @see https://docs.scriptable.app/filemanager/#-fileextension
     */
  fileExtension(filePath) {
    return this._invoke("fileExtension", Array.from(arguments));
  }
  /**
     * _Get path to a bookmarked file or folder._
     *
     * Gets the path to a bookmarked file or filder. Use file bookmarks to access files and folders outside Scriptables documents directory.
     *
     * You can edit your file bookmarks from Scriptables settings.
     *
     * The function will throw an error if the bookmark doesn't exist.
     *
     * Please beware that bookmarks created from Scriptables settings only can be used when running a script in the app and not from the Share Sheet, Siri and Shortcuts. If you wish to
     * use a bookmark from Siri or the Shortcuts app, the bookmark must be created using Scriptables "Create File Bookmark" shortcut action using the Shortcuts app.
     * @param name - Name of bookmark to create path for.
     * @see https://docs.scriptable.app/filemanager/#-bookmarkedpath
     */
  bookmarkedPath(name) {
    return this._invoke("bookmarkedPath", Array.from(arguments));
  }
  /**
     * _Check if a bookmark exists._
     *
     * Checks if a file bookmark exists with the specified name.
     *
     * You can edit your file bookmarks from Scriptables settings.
     *
     * Please beware that bookmarks created from Scriptables settings only can be used when running a script in the app and not from the Share Sheet, Siri and Shortcuts. If you wish to
     * use a bookmark from Siri or the Shortcuts app, the bookmark must be created using Scriptables "Create File Bookmark" shortcut action using the Shortcuts app.
     * @param name - Name of bookmark.
     * @see https://docs.scriptable.app/filemanager/#-bookmarkexists
     */
  bookmarkExists(name) {
    return this._invoke("bookmarkExists", Array.from(arguments));
  }
  /**
     * _Download file from iCloud if necessary._
     *
     * Downloads the file from iCloud if it has not already been downloaded. If you pass in a path to a file that is not stored in iCloud, the returned promise will be resolved
     * immediately making it safe to pass in any file path.
     * @param filePath - Path of file to download from iCloud.
     * @see https://docs.scriptable.app/filemanager/#-downloadfilefromicloud
     */
  downloadFileFromiCloud(filePath) {
    return this._invoke("downloadFileFromiCloud", Array.from(arguments));
  }
  /**
     * _Checks if a file is stored in iCloud._
     *
     * Checks if a file is stored in iCloud or locally on the device. The function returns false if the file does not exist. Check if a file exists using `fileExists(filePath)`
     * @param filePath - Path of file.
     * @see https://docs.scriptable.app/filemanager/#-isfilestoredinicloud
     */
  isFileStoredIniCloud(filePath) {
    return this._invoke("isFileStoredIniCloud", Array.from(arguments));
  }
  /**
     * _Checks if a file has been downloaded._
     *
     * If a file is stored in iCloud and it has not been downloaded, this function returns false. In that case, the file can be downloaded using `downloadFileFromiCloud(filePath`. If the
     * file is not stored in iCloud but rather locally on the device, this function returns true.
     *
     * The function returns false if the file does not exist. Check if a file exists using `fileExists(filePath)`
     * @param filePath - Path of file.
     * @see https://docs.scriptable.app/filemanager/#-isfiledownloaded
     */
  isFileDownloaded(filePath) {
    return this._invoke("isFileDownloaded", Array.from(arguments));
  }
  /**
     * _Reads the creation date of a file._
     *
     * The returned value will be null if the creation date cannot be read.
     * @param filePath - Path of file.
     * @see https://docs.scriptable.app/filemanager/#-creationdate
     */
  creationDate(filePath) {
    return this._invoke("creationDate", Array.from(arguments));
  }
  /**
     * _Reads the modification date of a file._
     *
     * The returned value will be null if the modification date cannot be read.
     * @param filePath - Path of file.
     * @see https://docs.scriptable.app/filemanager/#-modificationdate
     */
  modificationDate(filePath) {
    return this._invoke("modificationDate", Array.from(arguments));
  }
  /**
     * _Size of the file in kilobytes._
     *
     * The returned value will be null if the file size cannot be read.
     * @param filePath - Path of file.
     * @see https://docs.scriptable.app/filemanager/#-filesize
     */
  fileSize(filePath) {
    return this._invoke("fileSize", Array.from(arguments));
  }
  /**
     * _Reads all file bookmarks created in settings._
     *
     * File bookmarks are used to bookmark a file or a folder to read from it or write to it later. File bookmarks are created from Scriptables settings.
     *
     * This function returns all file bookmarks as an array of objects that take the following form.
     *
     *     {
     *       "name": "My Bookmark",
     *       "source": "host"
     *     }
     *
     * The source can either be `host` for file bookmarks that can be used in the app or `siri_shortcuts` for file bookmarks that can be used in Siri and Shortcuts.
     * @see https://docs.scriptable.app/filemanager/#-allfilebookmarks
     */
  allFileBookmarks() {
    return this._invoke("allFileBookmarks", Array.from(arguments));
  }
}
class AbsFont extends ScriptableObject {
  static type = "Font";
  /**
     * _Preferred font for large titles._
     * @see https://docs.scriptable.app/font/#largetitle
     */
  static largeTitle() {
    return this._invokeStatic("largeTitle", Array.from(arguments));
  }
  /**
     * _Preferred font for first level hierarchical headings._
     * @see https://docs.scriptable.app/font/#title1
     */
  static title1() {
    return this._invokeStatic("title1", Array.from(arguments));
  }
  /**
     * _Preferred font for second level hierarchical headings._
     * @see https://docs.scriptable.app/font/#title2
     */
  static title2() {
    return this._invokeStatic("title2", Array.from(arguments));
  }
  /**
     * _Preferred font for third level hierarchical headings._
     * @see https://docs.scriptable.app/font/#title3
     */
  static title3() {
    return this._invokeStatic("title3", Array.from(arguments));
  }
  /**
     * _Preferred font for headings._
     * @see https://docs.scriptable.app/font/#headline
     */
  static headline() {
    return this._invokeStatic("headline", Array.from(arguments));
  }
  /**
     * _Preferred font for subheadings._
     * @see https://docs.scriptable.app/font/#subheadline
     */
  static subheadline() {
    return this._invokeStatic("subheadline", Array.from(arguments));
  }
  /**
     * _Preferred font for body texts._
     * @see https://docs.scriptable.app/font/#body
     */
  static body() {
    return this._invokeStatic("body", Array.from(arguments));
  }
  /**
     * _Preferred font for callouts._
     * @see https://docs.scriptable.app/font/#callout
     */
  static callout() {
    return this._invokeStatic("callout", Array.from(arguments));
  }
  /**
     * _Preferred font for footnotes._
     * @see https://docs.scriptable.app/font/#footnote
     */
  static footnote() {
    return this._invokeStatic("footnote", Array.from(arguments));
  }
  /**
     * _Preferred font for standard captions._
     * @see https://docs.scriptable.app/font/#caption1
     */
  static caption1() {
    return this._invokeStatic("caption1", Array.from(arguments));
  }
  /**
     * _Preferred font for alternate captions._
     * @see https://docs.scriptable.app/font/#caption2
     */
  static caption2() {
    return this._invokeStatic("caption2", Array.from(arguments));
  }
  /**
     * _Creates a system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#systemfont
     */
  static systemFont(size) {
    return this._invokeStatic("systemFont", Array.from(arguments));
  }
  /**
     * _Creates an ultra light system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#ultralightsystemfont
     */
  static ultraLightSystemFont(size) {
    return this._invokeStatic("ultraLightSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a thin system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#thinsystemfont
     */
  static thinSystemFont(size) {
    return this._invokeStatic("thinSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a light system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#lightsystemfont
     */
  static lightSystemFont(size) {
    return this._invokeStatic("lightSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a regular system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#regularsystemfont
     */
  static regularSystemFont(size) {
    return this._invokeStatic("regularSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a medium system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#mediumsystemfont
     */
  static mediumSystemFont(size) {
    return this._invokeStatic("mediumSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a semibold system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#semiboldsystemfont
     */
  static semiboldSystemFont(size) {
    return this._invokeStatic("semiboldSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a bold system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#boldsystemfont
     */
  static boldSystemFont(size) {
    return this._invokeStatic("boldSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a heavy system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#heavysystemfont
     */
  static heavySystemFont(size) {
    return this._invokeStatic("heavySystemFont", Array.from(arguments));
  }
  /**
     * _Creates a font with the system appearance with the black weight._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#blacksystemfont
     */
  static blackSystemFont(size) {
    return this._invokeStatic("blackSystemFont", Array.from(arguments));
  }
  /**
     * _Creates an italic system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#italicsystemfont
     */
  static italicSystemFont(size) {
    return this._invokeStatic("italicSystemFont", Array.from(arguments));
  }
  /**
     * _Creates an ultra light monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#ultralightmonospacedsystemfont
     */
  static ultraLightMonospacedSystemFont(size) {
    return this._invokeStatic("ultraLightMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a thin monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#thinmonospacedsystemfont
     */
  static thinMonospacedSystemFont(size) {
    return this._invokeStatic("thinMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a light monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#lightmonospacedsystemfont
     */
  static lightMonospacedSystemFont(size) {
    return this._invokeStatic("lightMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a regular monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#regularmonospacedsystemfont
     */
  static regularMonospacedSystemFont(size) {
    return this._invokeStatic("regularMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a medium monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#mediummonospacedsystemfont
     */
  static mediumMonospacedSystemFont(size) {
    return this._invokeStatic("mediumMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a semibold monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#semiboldmonospacedsystemfont
     */
  static semiboldMonospacedSystemFont(size) {
    return this._invokeStatic("semiboldMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a bold monospaced system font.._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#boldmonospacedsystemfont
     */
  static boldMonospacedSystemFont(size) {
    return this._invokeStatic("boldMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a heavy monospaced system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#heavymonospacedsystemfont
     */
  static heavyMonospacedSystemFont(size) {
    return this._invokeStatic("heavyMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a monospaced system font with the black weight._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#blackmonospacedsystemfont
     */
  static blackMonospacedSystemFont(size) {
    return this._invokeStatic("blackMonospacedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates an ultra light and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#ultralightroundedsystemfont
     */
  static ultraLightRoundedSystemFont(size) {
    return this._invokeStatic("ultraLightRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a thin and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#thinroundedsystemfont
     */
  static thinRoundedSystemFont(size) {
    return this._invokeStatic("thinRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a light and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#lightroundedsystemfont
     */
  static lightRoundedSystemFont(size) {
    return this._invokeStatic("lightRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a regular and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#regularroundedsystemfont
     */
  static regularRoundedSystemFont(size) {
    return this._invokeStatic("regularRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a medium and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#mediumroundedsystemfont
     */
  static mediumRoundedSystemFont(size) {
    return this._invokeStatic("mediumRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a semibold and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#semiboldroundedsystemfont
     */
  static semiboldRoundedSystemFont(size) {
    return this._invokeStatic("semiboldRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a bold and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#boldroundedsystemfont
     */
  static boldRoundedSystemFont(size) {
    return this._invokeStatic("boldRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a heavy and rounded system font._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#heavyroundedsystemfont
     */
  static heavyRoundedSystemFont(size) {
    return this._invokeStatic("heavyRoundedSystemFont", Array.from(arguments));
  }
  /**
     * _Creates a rounded system font with the black weight._
     * @param size - Size of the text.
     * @see https://docs.scriptable.app/font/#blackroundedsystemfont
     */
  static blackRoundedSystemFont(size) {
    return this._invokeStatic("blackRoundedSystemFont", Array.from(arguments));
  }
}
class AbsImage extends ScriptableObject {
  static type = "Image";
  /**
     * _Creates an image from file._
     *
     * Loads an image from the specified file path. If the image could not be read, the function will return null.
     * @param filePath - File path to read image from.
     * @see https://docs.scriptable.app/image/#fromfile
     */
  static fromFile(filePath) {
    return this._invokeStatic("fromFile", Array.from(arguments));
  }
  /**
     * _Creates an image from raw data._
     *
     * Loads an image from the raw data. If the image could not be read, the function will return null.
     * @param data - Data to read image from.
     * @see https://docs.scriptable.app/image/#fromdata
     */
  static fromData(data) {
    return this._invokeStatic("fromData", Array.from(arguments));
  }
  get size() {
    return this._get("size");
  }
  set size(value) {
    this._set("size", value);
  }
}
class AbsLinearGradient extends ScriptableObject {
  static type = "LinearGradient";
  get colors() {
    return this._get("colors");
  }
  set colors(value) {
    this._set("colors", value);
  }
  get locations() {
    return this._get("locations");
  }
  set locations(value) {
    this._set("locations", value);
  }
  get startPoint() {
    return this._get("startPoint");
  }
  set startPoint(value) {
    this._set("startPoint", value);
  }
  get endPoint() {
    return this._get("endPoint");
  }
  set endPoint(value) {
    this._set("endPoint", value);
  }
}
class AbsListWidget extends ScriptableObject {
  static type = "ListWidget";
  get backgroundColor() {
    return this._get("backgroundColor");
  }
  set backgroundColor(value) {
    this._set("backgroundColor", value);
  }
  get backgroundImage() {
    return this._get("backgroundImage");
  }
  set backgroundImage(value) {
    this._set("backgroundImage", value);
  }
  get backgroundGradient() {
    return this._get("backgroundGradient");
  }
  set backgroundGradient(value) {
    this._set("backgroundGradient", value);
  }
  get addAccessoryWidgetBackground() {
    return this._get("addAccessoryWidgetBackground");
  }
  set addAccessoryWidgetBackground(value) {
    this._set("addAccessoryWidgetBackground", value);
  }
  get spacing() {
    return this._get("spacing");
  }
  set spacing(value) {
    this._set("spacing", value);
  }
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  get refreshAfterDate() {
    return this._get("refreshAfterDate");
  }
  set refreshAfterDate(value) {
    this._set("refreshAfterDate", value);
  }
  /**
     * _Add text to the widget._
     *
     * Adds a text element to the widget. Use the properties on the returned element to style the text.
     * @see https://docs.scriptable.app/listwidget/#-addtext
     */
  addText(text) {
    return this._invoke("addText", Array.from(arguments));
  }
  /**
     * _Add date to the widget._
     *
     * Adds a date element to the widget. Use the properties on the returned element to style the date.
     * @see https://docs.scriptable.app/listwidget/#-adddate
     */
  addDate(date) {
    return this._invoke("addDate", Array.from(arguments));
  }
  /**
     * _Add image to the widget._
     *
     * Adds an image element to the widget. Use the properties on the returned element to style the image.
     * @see https://docs.scriptable.app/listwidget/#-addimage
     */
  addImage(image) {
    return this._invoke("addImage", Array.from(arguments));
  }
  /**
     * _Add spacer._
     *
     * Adds a spacer to the widget. This can be used to offset the content vertically in the widget.
     * @param length - Length of the spacer. Pass null to create a spacer with a flexible length.
     * @see https://docs.scriptable.app/listwidget/#-addspacer
     */
  addSpacer(length) {
    return this._invoke("addSpacer", Array.from(arguments));
  }
  /**
     * _Add stack._
     *
     * Adds a stack to the widget. Stacks layout elements horizontally by default.
     * @see https://docs.scriptable.app/listwidget/#-addstack
     */
  addStack() {
    return this._invoke("addStack", Array.from(arguments));
  }
  /**
     * _Set padding._
     *
     * Sets the padding on each side of the widget.
     * @param top - Padding on the top edge.
     * @param leading - Padding on the leading edge.
     * @param bottom - Padding on the bottom edge.
     * @param trailing - Padding on the trailing edge.
     * @see https://docs.scriptable.app/listwidget/#-setpadding
     */
  setPadding(top, leading, bottom, trailing) {
    return this._invoke("setPadding", Array.from(arguments));
  }
  /**
     * _Use the default padding._
     *
     * Configure the widget to use the default padding. Any padding previously defined with `setPadding()` will be discarded.
     * @see https://docs.scriptable.app/listwidget/#-usedefaultpadding
     */
  useDefaultPadding() {
    return this._invoke("useDefaultPadding", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its small size.
     *
     * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
     * @see https://docs.scriptable.app/listwidget/#-presentsmall
     */
  presentSmall() {
    return this._invoke("presentSmall", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its medium size.
     *
     * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
     * @see https://docs.scriptable.app/listwidget/#-presentmedium
     */
  presentMedium() {
    return this._invoke("presentMedium", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its large size.
     *
     * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
     * @see https://docs.scriptable.app/listwidget/#-presentlarge
     */
  presentLarge() {
    return this._invoke("presentLarge", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its extra large size.
     *
     * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
     *
     * The extra large widget is only available on iPads running iOS 15 and newer.
     * @see https://docs.scriptable.app/listwidget/#-presentextralarge
     */
  presentExtraLarge() {
    return this._invoke("presentExtraLarge", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its accessory inline size that is suitable to be displayed above the clock on the Lock Screen.
     *
     * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
     * Screen, and as such, they cannot be previewed accurately in Scriptable.
     *
     * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
     *
     * The accessory inline widget is available on iPhones running iOS 16 and newer and can display a single image and a single text. Any additional elements will be filtered away during
     * presentation.
     * @see https://docs.scriptable.app/listwidget/#-presentaccessoryinline
     */
  presentAccessoryInline() {
    return this._invoke("presentAccessoryInline", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its circular accessory size that is suitable to be displayed below the clock on the Lock Screen.
     *
     * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
     * Screen, and as such, they cannot be previewed accurately in Scriptable.
     *
     * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
     *
     * The circular accessory widget is available on iPhones running iOS 16 and newer.
     * @see https://docs.scriptable.app/listwidget/#-presentaccessorycircular
     */
  presentAccessoryCircular() {
    return this._invoke("presentAccessoryCircular", Array.from(arguments));
  }
  /**
     * _Presents a preview of the widget._
     *
     * The widget is presented in its rectangular accessory size that is suitable to be displayed below the clock on the Lock Screen.
     *
     * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
     * Screen, and as such, they cannot be previewed accurately in Scriptable.
     *
     * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
     *
     * The rectangular accessory widget is available on iPhones running iOS 16 and newer.
     * @see https://docs.scriptable.app/listwidget/#-presentaccessoryrectangular
     */
  presentAccessoryRectangular() {
    return this._invoke("presentAccessoryRectangular", Array.from(arguments));
  }
}
class AbsMail extends ScriptableObject {
  static type = "Mail";
  get toRecipients() {
    return this._get("toRecipients");
  }
  set toRecipients(value) {
    this._set("toRecipients", value);
  }
  get ccRecipients() {
    return this._get("ccRecipients");
  }
  set ccRecipients(value) {
    this._set("ccRecipients", value);
  }
  get bccRecipients() {
    return this._get("bccRecipients");
  }
  set bccRecipients(value) {
    this._set("bccRecipients", value);
  }
  get subject() {
    return this._get("subject");
  }
  set subject(value) {
    this._set("subject", value);
  }
  get body() {
    return this._get("body");
  }
  set body(value) {
    this._set("body", value);
  }
  get isBodyHTML() {
    return this._get("isBodyHTML");
  }
  set isBodyHTML(value) {
    this._set("isBodyHTML", value);
  }
  get preferredSendingEmailAddress() {
    return this._get("preferredSendingEmailAddress");
  }
  set preferredSendingEmailAddress(value) {
    this._set("preferredSendingEmailAddress", value);
  }
  /**
     * _Send the mail._
     *
     * Presents a screen from which the mail can be sent. The mail will not be sent until you have confirmed it from the presented screen.
     * @see https://docs.scriptable.app/mail/#-send
     */
  send() {
    return this._invoke("send", Array.from(arguments));
  }
  /**
     * _Adds an image attachment to the mail._
     * @param image - Image to add to the mail.
     * @see https://docs.scriptable.app/mail/#-addimageattachment
     */
  addImageAttachment(image) {
    return this._invoke("addImageAttachment", Array.from(arguments));
  }
  /**
     * _Adds a file attachment to the mail._
     * @param filePath - Path of file to add to the mail.
     * @see https://docs.scriptable.app/mail/#-addfileattachment
     */
  addFileAttachment(filePath) {
    return this._invoke("addFileAttachment", Array.from(arguments));
  }
  /**
     * _Adds a data attachment to the mail._
     *
     * When adding a data attachment to the mail, you are responsible for providing a valid MIME type and filename. It is advised to use `addImageAttachment` and `addFileAttachment`
     * whenever possible.
     * @param data - Data representation of file to add to the mail.
     * @param mimeType - MIME type of file represented by the data.
     * @param filename - Name of the file represented by the data.
     * @see https://docs.scriptable.app/mail/#-adddataattachment
     */
  addDataAttachment(data, mimeType, filename) {
    return this._invoke("addDataAttachment", Array.from(arguments));
  }
}
class AbsMessage extends ScriptableObject {
  static type = "Message";
  get recipients() {
    return this._get("recipients");
  }
  set recipients(value) {
    this._set("recipients", value);
  }
  get body() {
    return this._get("body");
  }
  set body(value) {
    this._set("body", value);
  }
  /**
     * _Send the message._
     *
     * Presents a screen from which the message can be sent. The message will not be sent until you have confirmed it from the presented screen.
     * @see https://docs.scriptable.app/message/#-send
     */
  send() {
    return this._invoke("send", Array.from(arguments));
  }
  /**
     * _Adds an image attachment to the message._
     * @param image - Image to add to the message.
     * @see https://docs.scriptable.app/message/#-addimageattachment
     */
  addImageAttachment(image) {
    return this._invoke("addImageAttachment", Array.from(arguments));
  }
  /**
     * _Adds a file attachment to the message._
     * @param filePath - Path of file to add to the message.
     * @see https://docs.scriptable.app/message/#-addfileattachment
     */
  addFileAttachment(filePath) {
    return this._invoke("addFileAttachment", Array.from(arguments));
  }
  /**
     * _Adds a data attachment to the message._
     *
     * When adding a data attachment to the message, you are responsible for providing a valid Uniform Type Identifier and filename. It is advised to use `addImageAttachment` and
     * `addFileAttachment` whenever possible.
     * @param data - Data representation of file to add to the message.
     * @param uti - UTI of file represented by the data.
     * @param filename - Name of the file represented by the data.
     * @see https://docs.scriptable.app/message/#-adddataattachment
     */
  addDataAttachment(data, uti, filename) {
    return this._invoke("addDataAttachment", Array.from(arguments));
  }
}
class AbsNotification extends ScriptableObject {
  static type = "Notification";
  /**
     * _All pending notifications._
     *
     * Fetches all notifications that have been scheduled from Scriptable and are waiting to be delivered.
     * @see https://docs.scriptable.app/notification/#allpending
     */
  static allPending() {
    return this._invokeStatic("allPending", Array.from(arguments));
  }
  /**
     * _Delivered notifications displayed in the Notification Center._
     *
     * Fetches all notifications that have been scheduled from Scriptable and that are still displayed in the Notification Center of iOS.
     * @see https://docs.scriptable.app/notification/#alldelivered
     */
  static allDelivered() {
    return this._invokeStatic("allDelivered", Array.from(arguments));
  }
  /**
     * _Removes all pending notifications._
     *
     * Removes all notifications that have been scheduled from Scriptable and are waiting to be delivered.
     *
     * Use with caution. This removes all notifications scheduled across all of your scripts and the action cannot be undone.
     * @see https://docs.scriptable.app/notification/#removeallpending
     */
  static removeAllPending() {
    return this._invokeStatic("removeAllPending", Array.from(arguments));
  }
  /**
     * _Removes all delivered notifications._
     *
     * Removes all notifications that have been scheduled from Scriptable and that are still displayed in the Notification Center of iOS.
     * @see https://docs.scriptable.app/notification/#removealldelivered
     */
  static removeAllDelivered() {
    return this._invokeStatic("removeAllDelivered", Array.from(arguments));
  }
  /**
     * _Removes pending notifications._
     *
     * Removes notifications with the specified identifiers. The notifications are only removed if they are pending, that is they have been scheduled and are waiting to be delivered. To
     * remove delivered notifications, see `Notification.removeDelivered()`.
     * @see https://docs.scriptable.app/notification/#removepending
     */
  static removePending(identifiers) {
    return this._invokeStatic("removePending", Array.from(arguments));
  }
  /**
     * _Removes delivered notifications._
     *
     * Removes notifications with the specified identifiers. The notifications are only removed if they have been delivered. To remove pending notifications, see
     * `Notification.removePending()`.
     * @see https://docs.scriptable.app/notification/#removedelivered
     */
  static removeDelivered(identifiers) {
    return this._invokeStatic("removeDelivered", Array.from(arguments));
  }
  /**
     * _Resets the current notification._
     *
     * Effectively sets `args.notification` to null.
     *
     * When a notification scheduled from Scriptable has been tapped to open the app or while the app was open, `args.notification` will have a value until Scriptable is quit. You can
     * manually reset the value using `Notification.resetCurrent`.
     * @see https://docs.scriptable.app/notification/#resetcurrent
     */
  static resetCurrent() {
    return this._invokeStatic("resetCurrent", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get title() {
    return this._get("title");
  }
  set title(value) {
    this._set("title", value);
  }
  get subtitle() {
    return this._get("subtitle");
  }
  set subtitle(value) {
    this._set("subtitle", value);
  }
  get body() {
    return this._get("body");
  }
  set body(value) {
    this._set("body", value);
  }
  get preferredContentHeight() {
    return this._get("preferredContentHeight");
  }
  set preferredContentHeight(value) {
    this._set("preferredContentHeight", value);
  }
  get badge() {
    return this._get("badge");
  }
  set badge(value) {
    this._set("badge", value);
  }
  get threadIdentifier() {
    return this._get("threadIdentifier");
  }
  set threadIdentifier(value) {
    this._set("threadIdentifier", value);
  }
  get userInfo() {
    return this._get("userInfo");
  }
  set userInfo(value) {
    this._set("userInfo", value);
  }
  get sound() {
    return this._get("sound");
  }
  set sound(value) {
    this._set("sound", value);
  }
  get openURL() {
    return this._get("openURL");
  }
  set openURL(value) {
    this._set("openURL", value);
  }
  get deliveryDate() {
    return this._get("deliveryDate");
  }
  set deliveryDate(value) {
    this._set("deliveryDate", value);
  }
  get nextTriggerDate() {
    return this._get("nextTriggerDate");
  }
  set nextTriggerDate(value) {
    this._set("nextTriggerDate", value);
  }
  get scriptName() {
    return this._get("scriptName");
  }
  set scriptName(value) {
    this._set("scriptName", value);
  }
  get actions() {
    return this._get("actions");
  }
  set actions(value) {
    this._set("actions", value);
  }
  /**
     * _Schedules the notification._
     *
     * When a new notification is constructed, it must be scheduled, otherwise it will not be delivered. If an existing notification is modified, it must also be scheduled again for the
     * changes to take effect.
     * @see https://docs.scriptable.app/notification/#-schedule
     */
  schedule() {
    return this._invoke("schedule", Array.from(arguments));
  }
  /**
     * _Removes the notification._
     *
     * Removes all future triggers of the notification.
     * @see https://docs.scriptable.app/notification/#-remove
     */
  remove() {
    return this._invoke("remove", Array.from(arguments));
  }
  /**
     * _Sets the notification to be triggered on a date and time._
     * @param date - Date and time to trigger the notification on.
     * @see https://docs.scriptable.app/notification/#-settriggerdate
     */
  setTriggerDate(date) {
    return this._invoke("setTriggerDate", Array.from(arguments));
  }
  /**
     * _Sets the notification to be triggered daily._
     *
     * Sets the notification to be triggered on a specific time of the day. When the notification repeats, it will be sent at the same time on all future days. If the notification is not
     * repating it will be sent on the next occurrence of the specified time.
     * @param hour - Hour of the day to trigger the notification.
     * @param minute - Minute of the day to trigger the notification.
     * @param repeats - If true the notification will be sent daily on the specified time, otherwise it will only be sent once. Defaults to false.
     * @see https://docs.scriptable.app/notification/#-setdailytrigger
     */
  setDailyTrigger(hour, minute, repeats) {
    return this._invoke("setDailyTrigger", Array.from(arguments));
  }
  /**
     * _Sets the notification to be triggered weekly._
     *
     * Sets the notification to be triggered on a specific day of the week and a specific time of that day. When the notification repeats, it will be sent at the same time on all future
     * days. If the notification is not repating it will be sent on the next occurrence of the specified time.
     * @param weekday - Day of the week to trigger the notification.
     * @param hour - Hour of the day to trigger the notification.
     * @param minute - Minute of the day to trigger the notification.
     * @param repeats - If true the notification will be sent daily on the specified time, otherwise it will only be sent once. Defaults to false.
     * @see https://docs.scriptable.app/notification/#-setweeklytrigger
     */
  setWeeklyTrigger(weekday, hour, minute, repeats) {
    return this._invoke("setWeeklyTrigger", Array.from(arguments));
  }
  /**
     * _Adds an action button._
     *
     * Actions are shown as buttons in the notification. When screen space is unlimited, the system shows up to 10 actions. When the space is limited the system shows at most two actions.
     * @param title - Title of the action.
     * @param url - URL to open when choosing the action.
     * @param destructive - Optional. If set to true, the button is displayed with special highlighting to indicate that it performs a destructive task. Defaults to false.
     * @see https://docs.scriptable.app/notification/#-addaction
     */
  addAction(title, url, destructive) {
    return this._invoke("addAction", Array.from(arguments));
  }
}
class AbsPath extends ScriptableObject {
  static type = "Path";
  /**
     * _Moves to a point._
     *
     * Moves to a point without drawing a line between the current point and the new point.
     * @param point - Point to move to.
     * @see https://docs.scriptable.app/path/#-move
     */
  move(point) {
    return this._invoke("move", Array.from(arguments));
  }
  /**
     * _Adds a line to a point._
     *
     * Add a line from the current point, e.g. set using the move method, and to the new point.
     * @param point - Point to add line to.
     * @see https://docs.scriptable.app/path/#-addline
     */
  addLine(point) {
    return this._invoke("addLine", Array.from(arguments));
  }
  /**
     * _Adds a rectangle._
     *
     * This is a convenience function for adding a rectangle to the path starting from the lower left corner and drawing the lines counter-clockwise until the rectangle is closed.
     * @param rect - Rectangle to add.
     * @see https://docs.scriptable.app/path/#-addrect
     */
  addRect(rect) {
    return this._invoke("addRect", Array.from(arguments));
  }
  /**
     * _Adds an ellipse._
     *
     * Adds an ellipse incapsulated by the provided rectangle to the path.
     * @param rect - Rectangle incapsulating the ellipse.
     * @see https://docs.scriptable.app/path/#-addellipse
     */
  addEllipse(rect) {
    return this._invoke("addEllipse", Array.from(arguments));
  }
  /**
     * _Adds a rounded rectangle._
     *
     * Adds a rounded rectangle to the path. The corner width specifies the horizontal size of the corner and the corner height specifies the the vertical size of the corner.
     * @param rect - Rectangle to add.
     * @param cornerWidth - Horizontal size of the rounded corner.
     * @param cornerHeight - Vertical size of the rounded corner.
     * @see https://docs.scriptable.app/path/#-addroundedrect
     */
  addRoundedRect(rect, cornerWidth, cornerHeight) {
    return this._invoke("addRoundedRect", Array.from(arguments));
  }
  /**
     * _Adds a cubic curve to a point._
     *
     * Adds a cubic Bézier curve to the path with the specified end point and control points.
     * @param point - End point of the curve.
     * @param control1 - First control point of the curve.
     * @param control2 - Second control point of the curve.
     * @see https://docs.scriptable.app/path/#-addcurve
     */
  addCurve(point, control1, control2) {
    return this._invoke("addCurve", Array.from(arguments));
  }
  /**
     * _Adds a quadratic curve to a point._
     *
     * Adds a quadratic Bézier curve to the specified end point with the specified control point.
     * @param point - End point of the curve.
     * @param control - Control point of the curve.
     * @see https://docs.scriptable.app/path/#-addquadcurve
     */
  addQuadCurve(point, control) {
    return this._invoke("addQuadCurve", Array.from(arguments));
  }
  /**
     * _Adds a set of lines._
     *
     * Adds straight lines between an array of points. Calling this method is equivalent to calling the move function with the first point in the array of points and then calling addLine
     * on the subsequent points in the array.
     * @param points - Points to add lines between.
     * @see https://docs.scriptable.app/path/#-addlines
     */
  addLines(points) {
    return this._invoke("addLines", Array.from(arguments));
  }
  /**
     * _Adds a set of rectangles._
     *
     * Calling this is equivalent to repeatedly calling addRect.
     * @param rects - Rectangles to add.
     * @see https://docs.scriptable.app/path/#-addrects
     */
  addRects(rects) {
    return this._invoke("addRects", Array.from(arguments));
  }
  /**
     * _Closes a sub path._
     *
     * Adds a straight line from the current point to the start of the current subpath.
     * @see https://docs.scriptable.app/path/#-closesubpath
     */
  closeSubpath() {
    return this._invoke("closeSubpath", Array.from(arguments));
  }
}
class AbsPoint extends ScriptableObject {
  static type = "Point";
  get x() {
    return this._get("x");
  }
  set x(value) {
    this._set("x", value);
  }
  get y() {
    return this._get("y");
  }
  set y(value) {
    this._set("y", value);
  }
}
class AbsRect extends ScriptableObject {
  static type = "Rect";
  get minX() {
    return this._get("minX");
  }
  set minX(value) {
    this._set("minX", value);
  }
  get minY() {
    return this._get("minY");
  }
  set minY(value) {
    this._set("minY", value);
  }
  get maxX() {
    return this._get("maxX");
  }
  set maxX(value) {
    this._set("maxX", value);
  }
  get maxY() {
    return this._get("maxY");
  }
  set maxY(value) {
    this._set("maxY", value);
  }
  get x() {
    return this._get("x");
  }
  set x(value) {
    this._set("x", value);
  }
  get y() {
    return this._get("y");
  }
  set y(value) {
    this._set("y", value);
  }
  get width() {
    return this._get("width");
  }
  set width(value) {
    this._set("width", value);
  }
  get height() {
    return this._get("height");
  }
  set height(value) {
    this._set("height", value);
  }
  get origin() {
    return this._get("origin");
  }
  set origin(value) {
    this._set("origin", value);
  }
  get size() {
    return this._get("size");
  }
  set size(value) {
    this._set("size", value);
  }
}
class AbsRecurrenceRule extends ScriptableObject {
  static type = "RecurrenceRule";
  /**
     * _Constructs a daily recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
     * value of 3 specifies that the rule should repeat every third day.
     * @param interval - Interval at which to repeat the rule.
     * @see https://docs.scriptable.app/recurrencerule/#daily
     */
  static daily(interval) {
    return this._invokeStatic("daily", Array.from(arguments));
  }
  /**
     * _Constructs a daily recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
     * value of 3 specifies that the rule should repeat every third day.
     * @param interval - Interval at which to repeat the rule.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#dailyenddate
     */
  static dailyEndDate(interval, endDate) {
    return this._invokeStatic("dailyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a daily recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
     * value of 3 specifies that the rule should repeat every third day.
     * @param interval - Interval at which to repeat the rule.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#dailyoccurrencecount
     */
  static dailyOccurrenceCount(interval, occurrenceCount) {
    return this._invokeStatic("dailyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a weekly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     * @param interval - Interval at which to repeat the rule.
     * @see https://docs.scriptable.app/recurrencerule/#weekly
     */
  static weekly(interval) {
    return this._invokeStatic("weekly", Array.from(arguments));
  }
  /**
     * _Constructs a weekly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     * @param interval - Interval at which to repeat the rule.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#weeklyenddate
     */
  static weeklyEndDate(interval, endDate) {
    return this._invokeStatic("weeklyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a weekly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     * @param interval - Interval at which to repeat the rule.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#weeklyoccurrencecount
     */
  static weeklyOccurrenceCount(interval, occurrenceCount) {
    return this._invokeStatic("weeklyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a monthly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     * @param interval - Interval at which to repeat the rule.
     * @see https://docs.scriptable.app/recurrencerule/#monthly
     */
  static monthly(interval) {
    return this._invokeStatic("monthly", Array.from(arguments));
  }
  /**
     * _Constructs a monthly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     * @param interval - Interval at which to repeat the rule.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#monthlyenddate
     */
  static monthlyEndDate(interval, endDate) {
    return this._invokeStatic("monthlyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a monthly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     * @param interval - Interval at which to repeat the rule.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#monthlyoccurrencecount
     */
  static monthlyOccurrenceCount(interval, occurrenceCount) {
    return this._invokeStatic("monthlyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a yearly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third year.
     * @param interval - Interval at which to repeat the rule.
     * @see https://docs.scriptable.app/recurrencerule/#yearly
     */
  static yearly(interval) {
    return this._invokeStatic("yearly", Array.from(arguments));
  }
  /**
     * _Constructs a yearly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third year.
     * @param interval - Interval at which to repeat the rule.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#yearlyenddate
     */
  static yearlyEndDate(interval, endDate) {
    return this._invokeStatic("yearlyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a yearly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third year.
     * @param interval - Interval at which to repeat the rule.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#yearlyoccurrencecount
     */
  static yearlyOccurrenceCount(interval, occurrenceCount) {
    return this._invokeStatic("yearlyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a complex weekly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @see https://docs.scriptable.app/recurrencerule/#complexweekly
     */
  static complexWeekly(interval, daysOfTheWeek, setPositions) {
    return this._invokeStatic("complexWeekly", Array.from(arguments));
  }
  /**
     * _Constructs a complex weekly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#complexweeklyenddate
     */
  static complexWeeklyEndDate(interval, daysOfTheWeek, setPositions, endDate) {
    return this._invokeStatic("complexWeeklyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a complex weekly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
     * value of 3 specifies that the rule should repeat every third week.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#complexweeklyoccurrencecount
     */
  static complexWeeklyOccurrenceCount(interval, daysOfTheWeek, setPositions, occurrenceCount) {
    return this._invokeStatic("complexWeeklyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a complex monthly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @see https://docs.scriptable.app/recurrencerule/#complexmonthly
     */
  static complexMonthly(interval, daysOfTheWeek, daysOfTheMonth, setPositions) {
    return this._invokeStatic("complexMonthly", Array.from(arguments));
  }
  /**
     * _Constructs a complex monthly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#complexmonthlyenddate
     */
  static complexMonthlyEndDate(interval, daysOfTheWeek, daysOfTheMonth, setPositions, endDate) {
    return this._invokeStatic("complexMonthlyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a complex monthly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
     * value of 3 specifies that the rule should repeat every third month.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#complexmonthlyoccurrencecount
     */
  static complexMonthlyOccurrenceCount(interval, daysOfTheWeek, daysOfTheMonth, setPositions, occurrenceCount) {
    return this._invokeStatic("complexMonthlyOccurrenceCount", Array.from(arguments));
  }
  /**
     * _Constructs a complex yearly recurrence rule._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third year.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
     * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
     * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @see https://docs.scriptable.app/recurrencerule/#complexyearly
     */
  static complexYearly(interval, daysOfTheWeek, monthsOfTheYear, weeksOfTheYear, daysOfTheYear, setPositions) {
    return this._invokeStatic("complexYearly", Array.from(arguments));
  }
  /**
     * _Constructs a complex yearly recurrence rule with an end date._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third week.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
     * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
     * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param endDate - Date at which the recurrence rule should end.
     * @see https://docs.scriptable.app/recurrencerule/#complexyearlyenddate
     */
  static complexYearlyEndDate(interval, daysOfTheWeek, monthsOfTheYear, weeksOfTheYear, daysOfTheYear, setPositions, endDate) {
    return this._invokeStatic("complexYearlyEndDate", Array.from(arguments));
  }
  /**
     * _Constructs a complex yearly recurrence rule with an occurrence count._
     *
     * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
     * value of 3 specifies that the rule should repeat every third year.
     *
     * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
     * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
     * @param interval - Interval at which to repeat the rule.
     * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
     * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
     * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
     * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
     * @param setPositions - Filters which recurrences to include in the rule's frequency.
     * @param occurrenceCount - Number of times the rule should repeat before it ends.
     * @see https://docs.scriptable.app/recurrencerule/#complexyearlyoccurrencecount
     */
  static complexYearlyOccurrenceCount(interval, daysOfTheWeek, monthsOfTheYear, weeksOfTheYear, daysOfTheYear, setPositions, occurrenceCount) {
    return this._invokeStatic("complexYearlyOccurrenceCount", Array.from(arguments));
  }
}
class AbsRelativeDateTimeFormatter extends ScriptableObject {
  static type = "RelativeDateTimeFormatter";
  get locale() {
    return this._get("locale");
  }
  set locale(value) {
    this._set("locale", value);
  }
  /**
     * _Creates a localized string communicating the amount of time between two dates._
     *
     * Creates a localized textual representation of the amount of time between to dates. If the two dates are the same, the function will return "now". If the reference date is
     * yesterday, the function will return "yesterday". Other examples include "in 10 seconds", "2 hours ago", "last week" and "next year".
     * @param date - The date to create a relative date and time for.
     * @param referenceDate - The reference date that `date` is relative to.
     * @see https://docs.scriptable.app/relativedatetimeformatter/#-string
     */
  string(date, referenceDate) {
    return this._invoke("string", Array.from(arguments));
  }
  /**
     * _Prefers named dates and times._
     *
     * When using the named style, the formatter tries to find a suitable textual representation over a numeric value for the relative time, e.g. "now" instead of "in 0 seconds" and
     * "yesterday" instead of "1 day ago".
     *
     * When no named representation is found the formatter will fallback to using the numeric style.
     * @see https://docs.scriptable.app/relativedatetimeformatter/#-usenameddatetimestyle
     */
  useNamedDateTimeStyle() {
    return this._invoke("useNamedDateTimeStyle", Array.from(arguments));
  }
  /**
     * _Prefers numeric dates and times._
     *
     * When using the numeric style, the formatter will always prefer numeric representations over named representations. E.g. it will return "in 0 seconds" instead of "now" and "1 day
     * ago" instead of "yesteday".
     * @see https://docs.scriptable.app/relativedatetimeformatter/#-usenumericdatetimestyle
     */
  useNumericDateTimeStyle() {
    return this._invoke("useNumericDateTimeStyle", Array.from(arguments));
  }
}
class AbsReminder extends ScriptableObject {
  static type = "Reminder";
  /**
     * _Fetches the schedule of reminders._
     *
     * The fetched result contains reminders that are due today and reminders that are overdue. This is similar to the reminders shown in the Reminders apps "Scheduled" list. For
     * performance reasons iOS limits fetched results to events within a four year timespan.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#scheduled
     */
  static scheduled(calendars) {
    return this._invokeStatic("scheduled", Array.from(arguments));
  }
  /**
     * _Fetches all reminders._
     *
     * For performance reasons iOS limits fetched results to events within a four year timespan.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#all
     */
  static all(calendars) {
    return this._invokeStatic("all", Array.from(arguments));
  }
  /**
     * _Fetches all completed reminders._
     *
     * For performance reasons iOS limits fetched results to events within a four year timespan.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allcompleted
     */
  static allCompleted(calendars) {
    return this._invokeStatic("allCompleted", Array.from(arguments));
  }
  /**
     * _Fetches all incomplete reminders._
     *
     * For performance reasons iOS limits fetched results to events within a four year timespan.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allincomplete
     */
  static allIncomplete(calendars) {
    return this._invokeStatic("allIncomplete", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due today._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduetoday
     */
  static allDueToday(calendars) {
    return this._invokeStatic("allDueToday", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due today._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduetoday
     */
  static completedDueToday(calendars) {
    return this._invokeStatic("completedDueToday", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due today._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduetoday
     */
  static incompleteDueToday(calendars) {
    return this._invokeStatic("incompleteDueToday", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due tomorrow._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduetomorrow
     */
  static allDueTomorrow(calendars) {
    return this._invokeStatic("allDueTomorrow", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due tomorrow._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduetomorrow
     */
  static completedDueTomorrow(calendars) {
    return this._invokeStatic("completedDueTomorrow", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due tomorrow._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduetomorrow
     */
  static incompleteDueTomorrow(calendars) {
    return this._invokeStatic("incompleteDueTomorrow", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due yesterday._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#alldueyesterday
     */
  static allDueYesterday(calendars) {
    return this._invokeStatic("allDueYesterday", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due yesterday._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completeddueyesterday
     */
  static completedDueYesterday(calendars) {
    return this._invokeStatic("completedDueYesterday", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due yesterday._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompletedueyesterday
     */
  static incompleteDueYesterday(calendars) {
    return this._invokeStatic("incompleteDueYesterday", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due this week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduethisweek
     */
  static allDueThisWeek(calendars) {
    return this._invokeStatic("allDueThisWeek", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due this week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduethisweek
     */
  static completedDueThisWeek(calendars) {
    return this._invokeStatic("completedDueThisWeek", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due this week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduethisweek
     */
  static incompleteDueThisWeek(calendars) {
    return this._invokeStatic("incompleteDueThisWeek", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due next week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduenextweek
     */
  static allDueNextWeek(calendars) {
    return this._invokeStatic("allDueNextWeek", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due next week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduenextweek
     */
  static completedDueNextWeek(calendars) {
    return this._invokeStatic("completedDueNextWeek", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due next week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduenextweek
     */
  static incompleteDueNextWeek(calendars) {
    return this._invokeStatic("incompleteDueNextWeek", Array.from(arguments));
  }
  /**
     * _Fetches all reminders due last week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduelastweek
     */
  static allDueLastWeek(calendars) {
    return this._invokeStatic("allDueLastWeek", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders due last week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduelastweek
     */
  static completedDueLastWeek(calendars) {
    return this._invokeStatic("completedDueLastWeek", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders due last week._
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduelastweek
     */
  static incompleteDueLastWeek(calendars) {
    return this._invokeStatic("incompleteDueLastWeek", Array.from(arguments));
  }
  /**
     * _Fetches reminders completed today._
     *
     * Note that this does not take the due date into account. This will return all reminders that you have completed today.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedtoday
     */
  static completedToday(calendars) {
    return this._invokeStatic("completedToday", Array.from(arguments));
  }
  /**
     * _Fetches reminders completed this week._
     *
     * Note that this does not take the due date into account. This will return all reminders that you have completed this week.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedthisweek
     */
  static completedThisWeek(calendars) {
    return this._invokeStatic("completedThisWeek", Array.from(arguments));
  }
  /**
     * _Fetches reminders completed last week._
     *
     * Note that this does not take the due date into account. This will return all reminders that you have completed last week.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedlastweek
     */
  static completedLastWeek(calendars) {
    return this._invokeStatic("completedLastWeek", Array.from(arguments));
  }
  /**
     * _Fetches due reminders._
     *
     * Fetches reminders that are due within the time interval constituted by the start and end dates.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#allduebetween
     */
  static allDueBetween(startDate, endDate, calendars) {
    return this._invokeStatic("allDueBetween", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders._
     *
     * Fetches reminders that are completed and that were due within the time interval constituted by the start and end dates.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedduebetween
     */
  static completedDueBetween(startDate, endDate, calendars) {
    return this._invokeStatic("completedDueBetween", Array.from(arguments));
  }
  /**
     * _Fetches incomplete reminders._
     *
     * Fetches reminders that are incomplete and that were due within the time interval constituted by the start and end dates.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#incompleteduebetween
     */
  static incompleteDueBetween(startDate, endDate, calendars) {
    return this._invokeStatic("incompleteDueBetween", Array.from(arguments));
  }
  /**
     * _Fetches completed reminders._
     *
     * Fetches reminders that were completed within the time interval constituted by the start and end dates.
     * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
     * @see https://docs.scriptable.app/reminder/#completedbetween
     */
  static completedBetween(startDate, endDate, calendars) {
    return this._invokeStatic("completedBetween", Array.from(arguments));
  }
  get identifier() {
    return this._get("identifier");
  }
  set identifier(value) {
    this._set("identifier", value);
  }
  get title() {
    return this._get("title");
  }
  set title(value) {
    this._set("title", value);
  }
  get notes() {
    return this._get("notes");
  }
  set notes(value) {
    this._set("notes", value);
  }
  get isCompleted() {
    return this._get("isCompleted");
  }
  set isCompleted(value) {
    this._set("isCompleted", value);
  }
  get isOverdue() {
    return this._get("isOverdue");
  }
  set isOverdue(value) {
    this._set("isOverdue", value);
  }
  get priority() {
    return this._get("priority");
  }
  set priority(value) {
    this._set("priority", value);
  }
  get dueDate() {
    return this._get("dueDate");
  }
  set dueDate(value) {
    this._set("dueDate", value);
  }
  get dueDateIncludesTime() {
    return this._get("dueDateIncludesTime");
  }
  set dueDateIncludesTime(value) {
    this._set("dueDateIncludesTime", value);
  }
  get completionDate() {
    return this._get("completionDate");
  }
  set completionDate(value) {
    this._set("completionDate", value);
  }
  get creationDate() {
    return this._get("creationDate");
  }
  set creationDate(value) {
    this._set("creationDate", value);
  }
  get calendar() {
    return this._get("calendar");
  }
  set calendar(value) {
    this._set("calendar", value);
  }
  /**
     * _Adds a recurrence rule._
     *
     * Recurrence rules specify when the reminder should be repeated. See the documentation of RecurrenceRule for more information on creating rules.
     * @param recurrenceRule - Recurrence rule to add to the reminder.
     * @see https://docs.scriptable.app/reminder/#-addrecurrencerule
     */
  addRecurrenceRule(recurrenceRule) {
    return this._invoke("addRecurrenceRule", Array.from(arguments));
  }
  /**
     * _Removes all recurrence rules._
     * @see https://docs.scriptable.app/reminder/#-removeallrecurrencerules
     */
  removeAllRecurrenceRules() {
    return this._invoke("removeAllRecurrenceRules", Array.from(arguments));
  }
  /**
     * _Saves reminder._
     *
     * Saves changes to a reminder, inserting it into the calendar if it is newly created.
     * @see https://docs.scriptable.app/reminder/#-save
     */
  save() {
    return this._invoke("save", Array.from(arguments));
  }
  /**
     * _Removes reminder from calendar._
     * @see https://docs.scriptable.app/reminder/#-remove
     */
  remove() {
    return this._invoke("remove", Array.from(arguments));
  }
}
class AbsRequest extends ScriptableObject {
  static type = "Request";
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  get method() {
    return this._get("method");
  }
  set method(value) {
    this._set("method", value);
  }
  get headers() {
    return this._get("headers");
  }
  set headers(value) {
    this._set("headers", value);
  }
  get body() {
    return this._get("body");
  }
  set body(value) {
    this._set("body", value);
  }
  get timeoutInterval() {
    return this._get("timeoutInterval");
  }
  set timeoutInterval(value) {
    this._set("timeoutInterval", value);
  }
  get response() {
    return this._get("response");
  }
  set response(value) {
    this._set("response", value);
  }
  get allowInsecureRequest() {
    return this._get("allowInsecureRequest");
  }
  set allowInsecureRequest(value) {
    this._set("allowInsecureRequest", value);
  }
  get onRedirect() {
    return this._get("onRedirect");
  }
  set onRedirect(value) {
    this._set("onRedirect", value);
  }
  /**
     * _Sends request._
     *
     * Call to send the configured request to the specified URL. The raw response is provided when the returned promise is fulfilled.
     * @see https://docs.scriptable.app/request/#-load
     */
  load() {
    return this._invoke("load", Array.from(arguments));
  }
  /**
     * _Sends request and parses response as a string._
     *
     * Call to send the configured request to the specified URL. The response is parsed to a string and provided when the returned promise is fulfilled.
     * @see https://docs.scriptable.app/request/#-loadstring
     */
  loadString() {
    return this._invoke("loadString", Array.from(arguments));
  }
  /**
     * _Sends request and parses response as JSON._
     *
     * Call to send the configured request to the specified URL. The response is expected to be a valid JSON string and is parsed into an object.
     * @see https://docs.scriptable.app/request/#-loadjson
     */
  loadJSON() {
    return this._invoke("loadJSON", Array.from(arguments));
  }
  /**
     * _Sends request and parses response as an image._
     *
     * Call to send the configured request to the specified URL. The response is expected to be an image.
     * @see https://docs.scriptable.app/request/#-loadimage
     */
  loadImage() {
    return this._invoke("loadImage", Array.from(arguments));
  }
  /**
     * _Adds a parameter to a multipart request._
     *
     * Converts the request to a multipart request and adds a parameter with the specified name and value. Be aware that the `body` property on the request is ignored for multipart
     * requests as parameters and files added to the request constitutes the body.
     *
     * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
     * @param name - Name of the parameter.
     * @param value - Value of the parameter.
     * @see https://docs.scriptable.app/request/#-addparametertomultipart
     */
  addParameterToMultipart(name, value) {
    return this._invoke("addParameterToMultipart", Array.from(arguments));
  }
  /**
     * _Adds a file to a multipart request._
     *
     * Converts the request to a multipart request and adds the file to the request. Be aware that the `body` property on the request is ignored for multipart requests as parameters and
     * files added to the request constitutes the body.
     *
     * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
     * @param data - File data to add.
     * @param mimeType - MIME type of the file to add.
     * @param name - Name of the parameter which holds the file.
     * @param filename - Name of the file.
     * @see https://docs.scriptable.app/request/#-addfiledatatomultipart
     */
  addFileDataToMultipart(data, mimeType, name, filename) {
    return this._invoke("addFileDataToMultipart", Array.from(arguments));
  }
  /**
     * _Adds a file to a multipart request._
     *
     * Converts the request to a multipart request and adds the file to the request. The function will automatically determine the MIME type of the file as well as the filename. Be aware
     * that the `body` property on the request is ignored for multipart requests as parameters and files added to the request constitutes the body.
     *
     * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
     * @param filePath - Path of the file to add.
     * @param name - Name of the parameter which holds the file.
     * @param filename - Optional name of the uploaded file.
     * @see https://docs.scriptable.app/request/#-addfiletomultipart
     */
  addFileToMultipart(filePath, name, filename) {
    return this._invoke("addFileToMultipart", Array.from(arguments));
  }
  /**
     * _Adds an image to a multipart request._
     *
     * Converts the request to a multipart request and adds the image to the request. The function will automatically determine the MIME type of the file Be aware that the `body` property
     * on the request is ignored for multipart requests as parameters and files added to the request constitutes the body.
     *
     * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
     * @param image - Image to add.
     * @param name - Name of the parameter which holds the file.
     * @param filename - Optional name of the uploaded file.
     * @see https://docs.scriptable.app/request/#-addimagetomultipart
     */
  addImageToMultipart(image, name, filename) {
    return this._invoke("addImageToMultipart", Array.from(arguments));
  }
}
class AbsSFSymbol extends ScriptableObject {
  static type = "SFSymbol";
  /**
     * _Constructs an SF symbol._
     *
     * SF symbols are Apples configurable icons that are designed to look great with the San Francisco font.
     *
     * Symbols are referenced by their name. You can find the symbol names in [Apples SF Symbols app for macOS](https://developer.apple.com/sf-symbols/). You can also browse symbol names
     * in the [SF Symbols Browser](https://apps.apple.com/us/app/sf-symbols-browser/id1491161336) and [San Fransymbols](https://apps.apple.com/us/app/san-fransymbols/id1504761986) apps
     * for iOS.
     * @param symbolName - Name of the symbol.
     * @see https://docs.scriptable.app/sfsymbol/#named
     */
  static named(symbolName) {
    return this._invokeStatic("named", Array.from(arguments));
  }
  get image() {
    return this._get("image");
  }
  set image(value) {
    this._set("image", value);
  }
  /**
     * _Configures the symbol with the specified font information._
     * @see https://docs.scriptable.app/sfsymbol/#-applyfont
     */
  applyFont(font) {
    return this._invoke("applyFont", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use an ultra light weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applyultralightweight
     */
  applyUltraLightWeight() {
    return this._invoke("applyUltraLightWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a thin weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applythinweight
     */
  applyThinWeight() {
    return this._invoke("applyThinWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a light weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applylightweight
     */
  applyLightWeight() {
    return this._invoke("applyLightWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a regular weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applyregularweight
     */
  applyRegularWeight() {
    return this._invoke("applyRegularWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a medium weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applymediumweight
     */
  applyMediumWeight() {
    return this._invoke("applyMediumWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a semibold weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applysemiboldweight
     */
  applySemiboldWeight() {
    return this._invoke("applySemiboldWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a bold weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applyboldweight
     */
  applyBoldWeight() {
    return this._invoke("applyBoldWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a heavy weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applyheavyweight
     */
  applyHeavyWeight() {
    return this._invoke("applyHeavyWeight", Array.from(arguments));
  }
  /**
     * _Configures the symbol to use a black weight._
     * @see https://docs.scriptable.app/sfsymbol/#-applyblackweight
     */
  applyBlackWeight() {
    return this._invoke("applyBlackWeight", Array.from(arguments));
  }
}
class AbsSize extends ScriptableObject {
  static type = "Size";
  get width() {
    return this._get("width");
  }
  set width(value) {
    this._set("width", value);
  }
  get height() {
    return this._get("height");
  }
  set height(value) {
    this._set("height", value);
  }
}
class AbsTextField extends ScriptableObject {
  static type = "TextField";
  get text() {
    return this._get("text");
  }
  set text(value) {
    this._set("text", value);
  }
  get placeholder() {
    return this._get("placeholder");
  }
  set placeholder(value) {
    this._set("placeholder", value);
  }
  get isSecure() {
    return this._get("isSecure");
  }
  set isSecure(value) {
    this._set("isSecure", value);
  }
  get textColor() {
    return this._get("textColor");
  }
  set textColor(value) {
    this._set("textColor", value);
  }
  get font() {
    return this._get("font");
  }
  set font(value) {
    this._set("font", value);
  }
  /**
     * _Use the default keyboard for entering text._
     * @see https://docs.scriptable.app/textfield/#-setdefaultkeyboard
     */
  setDefaultKeyboard() {
    return this._invoke("setDefaultKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the numbers 0 through 9._
     * @see https://docs.scriptable.app/textfield/#-setnumberpadkeyboard
     */
  setNumberPadKeyboard() {
    return this._invoke("setNumberPadKeyboard", Array.from(arguments));
  }
  /**
     * _Use a numeric keyboard with a decimal point for entering text._
     * @see https://docs.scriptable.app/textfield/#-setdecimalpadkeyboard
     */
  setDecimalPadKeyboard() {
    return this._invoke("setDecimalPadKeyboard", Array.from(arguments));
  }
  /**
     * _Use a numeric keyboard with punctuation for entering text._
     * @see https://docs.scriptable.app/textfield/#-setnumbersandpunctuationkeyboard
     */
  setNumbersAndPunctuationKeyboard() {
    return this._invoke("setNumbersAndPunctuationKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the numbers 0 through 9 and the * and # characters._
     * @see https://docs.scriptable.app/textfield/#-setphonepadkeyboard
     */
  setPhonePadKeyboard() {
    return this._invoke("setPhonePadKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the space and period characters._
     * @see https://docs.scriptable.app/textfield/#-setwebsearchkeyboard
     */
  setWebSearchKeyboard() {
    return this._invoke("setWebSearchKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the @, period and space characters._
     * @see https://docs.scriptable.app/textfield/#-setemailaddresskeyboard
     */
  setEmailAddressKeyboard() {
    return this._invoke("setEmailAddressKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the period and slash characters and the ".com" string._
     * @see https://docs.scriptable.app/textfield/#-seturlkeyboard
     */
  setURLKeyboard() {
    return this._invoke("setURLKeyboard", Array.from(arguments));
  }
  /**
     * _Use a keyboard that prominently features the @ and # characters._
     * @see https://docs.scriptable.app/textfield/#-settwitterkeyboard
     */
  setTwitterKeyboard() {
    return this._invoke("setTwitterKeyboard", Array.from(arguments));
  }
  /**
     * _Left aligns the text._
     *
     * This is the default text alignment.
     * @see https://docs.scriptable.app/textfield/#-leftaligntext
     */
  leftAlignText() {
    return this._invoke("leftAlignText", Array.from(arguments));
  }
  /**
     * _Center aligns the text._
     * @see https://docs.scriptable.app/textfield/#-centeraligntext
     */
  centerAlignText() {
    return this._invoke("centerAlignText", Array.from(arguments));
  }
  /**
     * _Right aligns the text._
     * @see https://docs.scriptable.app/textfield/#-rightaligntext
     */
  rightAlignText() {
    return this._invoke("rightAlignText", Array.from(arguments));
  }
}
class AbsTimer extends ScriptableObject {
  static type = "Timer";
  /**
     * _Schedules a timer._
     *
     * This is a convenience function for creating a new timer. The created timer is instantly scheduled and will fire after the specified time interval.
     * @param timeInterval - The time interval to fire the timer at.
     * @param repeats - Whether the timer should repeat or not.
     * @param callback - The callback to be called when the timer fires.
     * @see https://docs.scriptable.app/timer/#schedule
     */
  static schedule(timeInterval, repeats, callback) {
    return this._invokeStatic("schedule", Array.from(arguments));
  }
  get timeInterval() {
    return this._get("timeInterval");
  }
  set timeInterval(value) {
    this._set("timeInterval", value);
  }
  get repeats() {
    return this._get("repeats");
  }
  set repeats(value) {
    this._set("repeats", value);
  }
  /**
     * _Schedules the timer._
     *
     * Schedules the timer using its configuration. The supplied function is called when the timer fires. To stop the timer from firing, call the `invalidate()` function.
     * @param callback - The callback to be called when the timer fires.
     * @see https://docs.scriptable.app/timer/#-schedule
     */
  schedule(callback) {
    return this._invoke("schedule", Array.from(arguments));
  }
  /**
     * _Stops the timer from firing._
     *
     * Stops the timer from firing ever again. Non-repeating timers are automatically invalidated after they have fired once. Repeating timers must be manually invalidated.
     * @see https://docs.scriptable.app/timer/#-invalidate
     */
  invalidate() {
    return this._invoke("invalidate", Array.from(arguments));
  }
}
class AbsUITable extends ScriptableObject {
  static type = "UITable";
  get showSeparators() {
    return this._get("showSeparators");
  }
  set showSeparators(value) {
    this._set("showSeparators", value);
  }
  /**
     * _Adds a row._
     *
     * Adds a row to the table. Rows are shown vertically in the table view, i.e. from the top and down. Rows are rendered in the order they are added.
     * @param row - Row to add.
     * @see https://docs.scriptable.app/uitable/#-addrow
     */
  addRow(row) {
    return this._invoke("addRow", Array.from(arguments));
  }
  /**
     * _Removes a row._
     *
     * Removes a row from the table.
     * @param row - Row to remove.
     * @see https://docs.scriptable.app/uitable/#-removerow
     */
  removeRow(row) {
    return this._invoke("removeRow", Array.from(arguments));
  }
  /**
     * _Removes all rows._
     *
     * Removes all rows from the table. If the table is presented, you must call the `reload` function in order for the changes to be reflected visually.
     * @see https://docs.scriptable.app/uitable/#-removeallrows
     */
  removeAllRows() {
    return this._invoke("removeAllRows", Array.from(arguments));
  }
  /**
     * _Reloads the table._
     *
     * If you add or remove rows while a table view is presented, you must reload the table in order for the changes to take effect.
     * @see https://docs.scriptable.app/uitable/#-reload
     */
  reload() {
    return this._invoke("reload", Array.from(arguments));
  }
  /**
     * _Presents the table._
     * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
     * @see https://docs.scriptable.app/uitable/#-present
     */
  present(fullscreen) {
    return this._invoke("present", Array.from(arguments));
  }
}
class AbsUITableCell extends ScriptableObject {
  static type = "UITableCell";
  /**
     * _Constructs a text cell._
     *
     * Constructs a new cell containing text.
     * @param title - Optional title to show in the cell.
     * @param subtitle - Optional subtitle shown below the title.
     * @see https://docs.scriptable.app/uitablecell/#text
     */
  static text(title, subtitle) {
    return this._invokeStatic("text", Array.from(arguments));
  }
  /**
     * _Constructs an image cell._
     *
     * Constructs a new cell containing an image.
     * @param image - Image to show in the cell.
     * @see https://docs.scriptable.app/uitablecell/#image
     */
  static image(image) {
    return this._invokeStatic("image", Array.from(arguments));
  }
  /**
     * _Constructs an image cell._
     *
     * Constructs a new cell that loads the image at the specified URL.
     * @param url - URL to image.
     * @see https://docs.scriptable.app/uitablecell/#imageaturl
     */
  static imageAtURL(url) {
    return this._invokeStatic("imageAtURL", Array.from(arguments));
  }
  /**
     * _Constructs a button cell._
     *
     * Constructs a new cell that contains a button. Set the `onTap` property to specify an action to performed when the button is tapped.
     * @param title - Title of the button.
     * @see https://docs.scriptable.app/uitablecell/#button
     */
  static button(title) {
    return this._invokeStatic("button", Array.from(arguments));
  }
  get widthWeight() {
    return this._get("widthWeight");
  }
  set widthWeight(value) {
    this._set("widthWeight", value);
  }
  get dismissOnTap() {
    return this._get("dismissOnTap");
  }
  set dismissOnTap(value) {
    this._set("dismissOnTap", value);
  }
  get titleColor() {
    return this._get("titleColor");
  }
  set titleColor(value) {
    this._set("titleColor", value);
  }
  get subtitleColor() {
    return this._get("subtitleColor");
  }
  set subtitleColor(value) {
    this._set("subtitleColor", value);
  }
  get titleFont() {
    return this._get("titleFont");
  }
  set titleFont(value) {
    this._set("titleFont", value);
  }
  get subtitleFont() {
    return this._get("subtitleFont");
  }
  set subtitleFont(value) {
    this._set("subtitleFont", value);
  }
  get onTap() {
    return this._get("onTap");
  }
  set onTap(value) {
    this._set("onTap", value);
  }
  /**
     * _Left aligns content._
     *
     * Specifies that the content in the cell should be left aligned.
     * @see https://docs.scriptable.app/uitablecell/#-leftaligned
     */
  leftAligned() {
    return this._invoke("leftAligned", Array.from(arguments));
  }
  /**
     * _Center aligns content._
     *
     * Specifies that the content in the cell should be center aligned.
     * @see https://docs.scriptable.app/uitablecell/#-centeraligned
     */
  centerAligned() {
    return this._invoke("centerAligned", Array.from(arguments));
  }
  /**
     * _Right aligns content._
     *
     * Specifies that the content in the cell should be right aligned.
     * @see https://docs.scriptable.app/uitablecell/#-rightaligned
     */
  rightAligned() {
    return this._invoke("rightAligned", Array.from(arguments));
  }
}
class AbsUITableRow extends ScriptableObject {
  static type = "UITableRow";
  get cellSpacing() {
    return this._get("cellSpacing");
  }
  set cellSpacing(value) {
    this._set("cellSpacing", value);
  }
  get height() {
    return this._get("height");
  }
  set height(value) {
    this._set("height", value);
  }
  get isHeader() {
    return this._get("isHeader");
  }
  set isHeader(value) {
    this._set("isHeader", value);
  }
  get dismissOnSelect() {
    return this._get("dismissOnSelect");
  }
  set dismissOnSelect(value) {
    this._set("dismissOnSelect", value);
  }
  get backgroundColor() {
    return this._get("backgroundColor");
  }
  set backgroundColor(value) {
    this._set("backgroundColor", value);
  }
  get onSelect() {
    return this._get("onSelect");
  }
  set onSelect(value) {
    this._set("onSelect", value);
  }
  /**
     * _Adds a cell._
     *
     * Adds a cell to the row. Note that cells are shown in the order they are added to the row.
     * @param cell - Cell to add to the row.
     * @see https://docs.scriptable.app/uitablerow/#-addcell
     */
  addCell(cell) {
    return this._invoke("addCell", Array.from(arguments));
  }
  /**
     * _Adds a text cell._
     *
     * Constructs a new cell containing the specified string and adds it to the row.
     * @param title - Optional title to show in the cell.
     * @param subtitle - Optional subtitle shown below the title in the cell.
     * @see https://docs.scriptable.app/uitablerow/#-addtext
     */
  addText(title, subtitle) {
    return this._invoke("addText", Array.from(arguments));
  }
  /**
     * _Adds an image cell._
     *
     * Constructs a new cell containing the specified image and adds it to the row.
     * @param image - Image to show in the cell.
     * @see https://docs.scriptable.app/uitablerow/#-addimage
     */
  addImage(image) {
    return this._invoke("addImage", Array.from(arguments));
  }
  /**
     * _Adds an image cell._
     *
     * Constructs a new cell that loads the image at the specified url and adds the cell to the row.
     * @param url - URL to image.
     * @see https://docs.scriptable.app/uitablerow/#-addimageaturl
     */
  addImageAtURL(url) {
    return this._invoke("addImageAtURL", Array.from(arguments));
  }
  /**
     * _Adds a button cell._
     *
     * Constructs a new cell that contains a button. Set the `onTap` property to specify an action to performed when the button is tapped.
     * @param title - Title of the button.
     * @see https://docs.scriptable.app/uitablerow/#-addbutton
     */
  addButton(title) {
    return this._invoke("addButton", Array.from(arguments));
  }
}
class AbsWebView extends ScriptableObject {
  static type = "WebView";
  /**
     * _Loads HTML and renders it._
     * @param html - HTML to load and render.
     * @param baseURL - Optional. Base URL used to resolve relative URLs in the HTML.
     * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
     * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
     * @see https://docs.scriptable.app/webview/#loadhtml
     */
  static loadHTML(html, baseURL, preferredSize, fullscreen) {
    return this._invokeStatic("loadHTML", Array.from(arguments));
  }
  /**
     * _Loads a file and renders it._
     *
     * Files can be of various types, including HTML files and images.
     *
     * The supplied HTML file can reference files and nested directories in the same directory as the HTML file resides.
     *
     * The optional `preferredSize` parameter is ignored unless the script is run in a Siri Shortcut.
     *
     * If you are displaying large images in a memory constrained envrionment, for example in a Siri Shortcut, you should use the WebView bridge instead of the QuickLook bridge. The
     * technical reason for this is that a Siri Shortcut and other app extension processes have very limited memory and loading a very large image will cause the app extension to be
     * terminated. However, the web view will run in a different process meaning that it is not affected by the same memory constraints.
     * @param fileURL - URL of the file to load and render.
     * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
     * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
     * @see https://docs.scriptable.app/webview/#loadfile
     */
  static loadFile(fileURL, preferredSize, fullscreen) {
    return this._invokeStatic("loadFile", Array.from(arguments));
  }
  /**
     * _Loads URL in web view and presents the web view._
     *
     * The optional `preferredSize` parameter is ignored unless the script is run in a Siri Shortcut.
     * @param url - URL to load into the web view.
     * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
     * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
     * @see https://docs.scriptable.app/webview/#loadurl
     */
  static loadURL(url, preferredSize, fullscreen) {
    return this._invokeStatic("loadURL", Array.from(arguments));
  }
  get shouldAllowRequest() {
    return this._get("shouldAllowRequest");
  }
  set shouldAllowRequest(value) {
    this._set("shouldAllowRequest", value);
  }
  /**
     * _Loads URL in web view._
     *
     * Loads the URL in the web view. The returned promise will complete once the web view has finished loading.
     * @param url - URL to load into the web view.
     * @see https://docs.scriptable.app/webview/#-loadurl
     */
  loadURL(url) {
    return this._invoke("loadURL", Array.from(arguments));
  }
  /**
     * _Loads request in web view._
     *
     * When loading a request into the web view, the HTTP method, body and headers of the request will be respected. The onRedirect function on the request will not be invoked.
     * @param request - Request to load into the web view.
     * @see https://docs.scriptable.app/webview/#-loadrequest
     */
  loadRequest(request) {
    return this._invoke("loadRequest", Array.from(arguments));
  }
  /**
     * _Loads HTML in web view._
     *
     * Loads the HTML into the web view. The returned promise will complete once the web view has finished loading.
     * @param html - HTML to load into the web view.
     * @param baseURL - Optional. Base URL used to resolve relative URLs in the HTML.
     * @see https://docs.scriptable.app/webview/#-loadhtml
     */
  loadHTML(html, baseURL) {
    return this._invoke("loadHTML", Array.from(arguments));
  }
  /**
     * _Loads file in the web view._
     *
     * Files can be of various types, including HTML files and images.
     *
     * The supplied HTML file can reference files and nested directories in the same directory as the HTML file resides.
     * @param fileURL - URL of the file to load and render.
     * @see https://docs.scriptable.app/webview/#-loadfile
     */
  loadFile(fileURL) {
    return this._invoke("loadFile", Array.from(arguments));
  }
  /**
     * _Evaluates JavaScript in the web view._
     *
     * Evaluates JavaScript in the current context of the web view. The returned promise carries the result of evaluating the JavaScript.
     *
     * When passing `false` to the `useCallback` parameter, which is the default value, evaluation will terminate after evaluating the last line of the JavaScript. The value on the last
     * line of the script will be carried by the promise returned by `evaluateJavaScript`.
     *
     * When passing `true` to the `useCallback` parameter, evaluation will only complete after the globally available `completion` function is called. Any value passed to the function,
     * will be carried by the promise returned by `evaluateJavaScript`.
     *
     * The log is available from the evaluated JavaScript, i.e. messages passed to the globally available `log` and `logError` functions will be shown in the log.
     * @param javaScript - JavaScript to evaluate in the web view.
     * @param useCallback - Optional. If true the web view waits for the globally available completion function of the web view to be called before terminating. Defaults to false.
     * @see https://docs.scriptable.app/webview/#-evaluatejavascript
     */
  evaluateJavaScript(javaScript, useCallback) {
    return this._invoke("evaluateJavaScript", Array.from(arguments));
  }
  /**
     * _Reads and returns HTML from the loaded website._
     * @see https://docs.scriptable.app/webview/#-gethtml
     */
  getHTML() {
    return this._invoke("getHTML", Array.from(arguments));
  }
  /**
     * _Presents the web view._
     *
     * The web view is presented with the content that has been loaded into it.
     * @param fullscreen - Set to true to present the web view in fullscreen. Defaults to false.
     * @see https://docs.scriptable.app/webview/#-present
     */
  present(fullscreen) {
    return this._invoke("present", Array.from(arguments));
  }
  /**
     * _Waits for the web view to load._
     *
     * The returned promise will be fulfilled when the web view finishes loading. If the load fails, the promise will be fulfilled with an error. Use this with caution. If the web view is
     * not loading a new page or is not about to load a new page, the returned promise will never be fulfilled. This limitation exists because Scriptable cannot determine if a web view is
     * about to load a page in cases where evaluating JavaScript in the web view causes a new page to load.
     *
     * Generally this should only be used when loading causing a new page to load from `evaluateJavaScript`. In other cases, e.g. when loading a URL using `loadURL`, the returned promise
     * will be fulfilled when the page has been loaded.
     * @see https://docs.scriptable.app/webview/#-waitforload
     */
  waitForLoad() {
    return this._invoke("waitForLoad", Array.from(arguments));
  }
}
class AbsWidgetDate extends ScriptableObject {
  static type = "WidgetDate";
  get date() {
    return this._get("date");
  }
  set date(value) {
    this._set("date", value);
  }
  get textColor() {
    return this._get("textColor");
  }
  set textColor(value) {
    this._set("textColor", value);
  }
  get font() {
    return this._get("font");
  }
  set font(value) {
    this._set("font", value);
  }
  get textOpacity() {
    return this._get("textOpacity");
  }
  set textOpacity(value) {
    this._set("textOpacity", value);
  }
  get lineLimit() {
    return this._get("lineLimit");
  }
  set lineLimit(value) {
    this._set("lineLimit", value);
  }
  get minimumScaleFactor() {
    return this._get("minimumScaleFactor");
  }
  set minimumScaleFactor(value) {
    this._set("minimumScaleFactor", value);
  }
  get shadowColor() {
    return this._get("shadowColor");
  }
  set shadowColor(value) {
    this._set("shadowColor", value);
  }
  get shadowRadius() {
    return this._get("shadowRadius");
  }
  set shadowRadius(value) {
    this._set("shadowRadius", value);
  }
  get shadowOffset() {
    return this._get("shadowOffset");
  }
  set shadowOffset(value) {
    this._set("shadowOffset", value);
  }
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  /**
     * _Left aligns the text._
     *
     * Specifies that text should be left aligned. This is the default.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to left in a horizontal stack, you should place a spacer after the
     * text.
     * @see https://docs.scriptable.app/widgetdate/#-leftaligntext
     */
  leftAlignText() {
    return this._invoke("leftAlignText", Array.from(arguments));
  }
  /**
     * _Center aligns the text._
     *
     * Specifies that text should be center aligned.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text in the center of a horizontal stack, you should place a spacer both
     * before and after the text.
     * @see https://docs.scriptable.app/widgetdate/#-centeraligntext
     */
  centerAlignText() {
    return this._invoke("centerAlignText", Array.from(arguments));
  }
  /**
     * _Right aligns the text._
     *
     * Specifies that text should be right aligned.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to the right in a horizontal stack, you should place a spacer
     * before the text.
     * @see https://docs.scriptable.app/widgetdate/#-rightaligntext
     */
  rightAlignText() {
    return this._invoke("rightAlignText", Array.from(arguments));
  }
  /**
     * _Display time component of the date._
     *
     * Example output: 11:23PM
     * @see https://docs.scriptable.app/widgetdate/#-applytimestyle
     */
  applyTimeStyle() {
    return this._invoke("applyTimeStyle", Array.from(arguments));
  }
  /**
     * _Display entire date._
     *
     * Example output: June 3, 2019
     *
     * This is the default.
     * @see https://docs.scriptable.app/widgetdate/#-applydatestyle
     */
  applyDateStyle() {
    return this._invoke("applyDateStyle", Array.from(arguments));
  }
  /**
     * _Display date as relative to now._
     *
     * Example output: 2 hours, 23 minutes 1 year, 1 month
     * @see https://docs.scriptable.app/widgetdate/#-applyrelativestyle
     */
  applyRelativeStyle() {
    return this._invoke("applyRelativeStyle", Array.from(arguments));
  }
  /**
     * _Display date as offset from now._
     *
     * Example output: +2 hours -3 months
     * @see https://docs.scriptable.app/widgetdate/#-applyoffsetstyle
     */
  applyOffsetStyle() {
    return this._invoke("applyOffsetStyle", Array.from(arguments));
  }
  /**
     * _Display date as timer counting from now._
     *
     * Example output: 2:32 36:59:01
     * @see https://docs.scriptable.app/widgetdate/#-applytimerstyle
     */
  applyTimerStyle() {
    return this._invoke("applyTimerStyle", Array.from(arguments));
  }
}
class AbsWidgetImage extends ScriptableObject {
  static type = "WidgetImage";
  get image() {
    return this._get("image");
  }
  set image(value) {
    this._set("image", value);
  }
  get resizable() {
    return this._get("resizable");
  }
  set resizable(value) {
    this._set("resizable", value);
  }
  get imageSize() {
    return this._get("imageSize");
  }
  set imageSize(value) {
    this._set("imageSize", value);
  }
  get imageOpacity() {
    return this._get("imageOpacity");
  }
  set imageOpacity(value) {
    this._set("imageOpacity", value);
  }
  get cornerRadius() {
    return this._get("cornerRadius");
  }
  set cornerRadius(value) {
    this._set("cornerRadius", value);
  }
  get borderWidth() {
    return this._get("borderWidth");
  }
  set borderWidth(value) {
    this._set("borderWidth", value);
  }
  get borderColor() {
    return this._get("borderColor");
  }
  set borderColor(value) {
    this._set("borderColor", value);
  }
  get containerRelativeShape() {
    return this._get("containerRelativeShape");
  }
  set containerRelativeShape(value) {
    this._set("containerRelativeShape", value);
  }
  get tintColor() {
    return this._get("tintColor");
  }
  set tintColor(value) {
    this._set("tintColor", value);
  }
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  /**
     * _Left aligns the image._
     *
     * Specifies that image should be left aligned. This is the default.
     * @see https://docs.scriptable.app/widgetimage/#-leftalignimage
     */
  leftAlignImage() {
    return this._invoke("leftAlignImage", Array.from(arguments));
  }
  /**
     * _Center aligns the image._
     *
     * Specifies that image should be center aligned.
     * @see https://docs.scriptable.app/widgetimage/#-centeralignimage
     */
  centerAlignImage() {
    return this._invoke("centerAlignImage", Array.from(arguments));
  }
  /**
     * _Right aligns the image._
     *
     * Specifies that image should be right aligned.
     * @see https://docs.scriptable.app/widgetimage/#-rightalignimage
     */
  rightAlignImage() {
    return this._invoke("rightAlignImage", Array.from(arguments));
  }
  /**
     * _Uses fitting content mode._
     *
     * The image will fit the available space. This content mode is the default.
     * @see https://docs.scriptable.app/widgetimage/#-applyfittingcontentmode
     */
  applyFittingContentMode() {
    return this._invoke("applyFittingContentMode", Array.from(arguments));
  }
  /**
     * _Uses filling content mode._
     *
     * The image will fill the available space.
     * @see https://docs.scriptable.app/widgetimage/#-applyfillingcontentmode
     */
  applyFillingContentMode() {
    return this._invoke("applyFillingContentMode", Array.from(arguments));
  }
}
class AbsWidgetSpacer extends ScriptableObject {
  static type = "WidgetSpacer";
  get length() {
    return this._get("length");
  }
  set length(value) {
    this._set("length", value);
  }
}
class AbsWidgetStack extends ScriptableObject {
  static type = "WidgetStack";
  get backgroundColor() {
    return this._get("backgroundColor");
  }
  set backgroundColor(value) {
    this._set("backgroundColor", value);
  }
  get backgroundImage() {
    return this._get("backgroundImage");
  }
  set backgroundImage(value) {
    this._set("backgroundImage", value);
  }
  get backgroundGradient() {
    return this._get("backgroundGradient");
  }
  set backgroundGradient(value) {
    this._set("backgroundGradient", value);
  }
  get spacing() {
    return this._get("spacing");
  }
  set spacing(value) {
    this._set("spacing", value);
  }
  get size() {
    return this._get("size");
  }
  set size(value) {
    this._set("size", value);
  }
  get cornerRadius() {
    return this._get("cornerRadius");
  }
  set cornerRadius(value) {
    this._set("cornerRadius", value);
  }
  get borderWidth() {
    return this._get("borderWidth");
  }
  set borderWidth(value) {
    this._set("borderWidth", value);
  }
  get borderColor() {
    return this._get("borderColor");
  }
  set borderColor(value) {
    this._set("borderColor", value);
  }
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  /**
     * _Add text to the stack._
     *
     * Adds a text element to the stack. Use the properties on the returned element to style the text.
     * @see https://docs.scriptable.app/widgetstack/#-addtext
     */
  addText(text) {
    return this._invoke("addText", Array.from(arguments));
  }
  /**
     * _Add date to the widget._
     *
     * Adds a date element to the widget. Use the properties on the returned element to style the date.
     * @see https://docs.scriptable.app/widgetstack/#-adddate
     */
  addDate(date) {
    return this._invoke("addDate", Array.from(arguments));
  }
  /**
     * _Add image to the stack._
     *
     * Adds an image element to the stack. Use the properties on the returned element to style the image.
     * @see https://docs.scriptable.app/widgetstack/#-addimage
     */
  addImage(image) {
    return this._invoke("addImage", Array.from(arguments));
  }
  /**
     * _Add spacer._
     *
     * Adds a spacer to the stack. This can be used to offset the content horizontally in the stack.
     * @param length - Length of the spacer. Pass null to create a spacer with a flexible length.
     * @see https://docs.scriptable.app/widgetstack/#-addspacer
     */
  addSpacer(length) {
    return this._invoke("addSpacer", Array.from(arguments));
  }
  /**
     * _Add stack._
     *
     * Adds a stack to the widget. Stacks layout elements horizontally by default.
     * @see https://docs.scriptable.app/widgetstack/#-addstack
     */
  addStack() {
    return this._invoke("addStack", Array.from(arguments));
  }
  /**
     * _Set padding._
     *
     * Sets the padding on each side of the stack.
     * @param top - Padding on the top edge.
     * @param leading - Padding on the leading edge.
     * @param bottom - Padding on the bottom edge.
     * @param trailing - Padding on the trailing edge.
     * @see https://docs.scriptable.app/widgetstack/#-setpadding
     */
  setPadding(top, leading, bottom, trailing) {
    return this._invoke("setPadding", Array.from(arguments));
  }
  /**
     * _Use the default padding._
     *
     * Configure the stack to use the default padding. Any padding previously defined with `setPadding()` will be discarded.
     * @see https://docs.scriptable.app/widgetstack/#-usedefaultpadding
     */
  useDefaultPadding() {
    return this._invoke("useDefaultPadding", Array.from(arguments));
  }
  /**
     * _Top aligns the content._
     *
     * Specifies that the content should be top aligned. This is the default.
     * @see https://docs.scriptable.app/widgetstack/#-topaligncontent
     */
  topAlignContent() {
    return this._invoke("topAlignContent", Array.from(arguments));
  }
  /**
     * _Center aligns the content._
     *
     * Specifies that the content should be center aligned.
     * @see https://docs.scriptable.app/widgetstack/#-centeraligncontent
     */
  centerAlignContent() {
    return this._invoke("centerAlignContent", Array.from(arguments));
  }
  /**
     * _Bottom aligns the content._
     *
     * Specifies that the content should be bottom aligned.
     * @see https://docs.scriptable.app/widgetstack/#-bottomaligncontent
     */
  bottomAlignContent() {
    return this._invoke("bottomAlignContent", Array.from(arguments));
  }
  /**
     * _Layout elements horizontally._
     *
     * Specifies that the stack should layout elements horizontally. This is the default.
     * @see https://docs.scriptable.app/widgetstack/#-layouthorizontally
     */
  layoutHorizontally() {
    return this._invoke("layoutHorizontally", Array.from(arguments));
  }
  /**
     * _Layout elements vertically._
     *
     * Specifies that the stack should layout elements vertically.
     * @see https://docs.scriptable.app/widgetstack/#-layoutvertically
     */
  layoutVertically() {
    return this._invoke("layoutVertically", Array.from(arguments));
  }
}
class AbsWidgetText extends ScriptableObject {
  static type = "WidgetText";
  get text() {
    return this._get("text");
  }
  set text(value) {
    this._set("text", value);
  }
  get textColor() {
    return this._get("textColor");
  }
  set textColor(value) {
    this._set("textColor", value);
  }
  get font() {
    return this._get("font");
  }
  set font(value) {
    this._set("font", value);
  }
  get textOpacity() {
    return this._get("textOpacity");
  }
  set textOpacity(value) {
    this._set("textOpacity", value);
  }
  get lineLimit() {
    return this._get("lineLimit");
  }
  set lineLimit(value) {
    this._set("lineLimit", value);
  }
  get minimumScaleFactor() {
    return this._get("minimumScaleFactor");
  }
  set minimumScaleFactor(value) {
    this._set("minimumScaleFactor", value);
  }
  get shadowColor() {
    return this._get("shadowColor");
  }
  set shadowColor(value) {
    this._set("shadowColor", value);
  }
  get shadowRadius() {
    return this._get("shadowRadius");
  }
  set shadowRadius(value) {
    this._set("shadowRadius", value);
  }
  get shadowOffset() {
    return this._get("shadowOffset");
  }
  set shadowOffset(value) {
    this._set("shadowOffset", value);
  }
  get url() {
    return this._get("url");
  }
  set url(value) {
    this._set("url", value);
  }
  /**
     * _Left aligns the text._
     *
     * Specifies that text should be left aligned. This is the default.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to left in a horizontal stack, you should place a spacer after the
     * text.
     * @see https://docs.scriptable.app/widgettext/#-leftaligntext
     */
  leftAlignText() {
    return this._invoke("leftAlignText", Array.from(arguments));
  }
  /**
     * _Center aligns the text._
     *
     * Specifies that text should be center aligned.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text in the center of a horizontal stack, you should place a spacer both
     * before and after the text.
     * @see https://docs.scriptable.app/widgettext/#-centeraligntext
     */
  centerAlignText() {
    return this._invoke("centerAlignText", Array.from(arguments));
  }
  /**
     * _Right aligns the text._
     *
     * Specifies that text should be right aligned.
     *
     * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to the right in a horizontal stack, you should place a spacer
     * before the text.
     * @see https://docs.scriptable.app/widgettext/#-rightaligntext
     */
  rightAlignText() {
    return this._invoke("rightAlignText", Array.from(arguments));
  }
}
class AbsXMLParser extends ScriptableObject {
  static type = "XMLParser";
  get string() {
    return this._get("string");
  }
  set string(value) {
    this._set("string", value);
  }
  get didStartDocument() {
    return this._get("didStartDocument");
  }
  set didStartDocument(value) {
    this._set("didStartDocument", value);
  }
  get didEndDocument() {
    return this._get("didEndDocument");
  }
  set didEndDocument(value) {
    this._set("didEndDocument", value);
  }
  get didStartElement() {
    return this._get("didStartElement");
  }
  set didStartElement(value) {
    this._set("didStartElement", value);
  }
  get didEndElement() {
    return this._get("didEndElement");
  }
  set didEndElement(value) {
    this._set("didEndElement", value);
  }
  get foundCharacters() {
    return this._get("foundCharacters");
  }
  set foundCharacters(value) {
    this._set("foundCharacters", value);
  }
  get parseErrorOccurred() {
    return this._get("parseErrorOccurred");
  }
  set parseErrorOccurred(value) {
    this._set("parseErrorOccurred", value);
  }
  /**
     * _Starts parsing._
     *
     * Before calling this function you should ensure that the parser is correctly configured, i.e. the necessary callback functions should be set.
     * @see https://docs.scriptable.app/xmlparser/#-parse
     */
  parse() {
    return this._invoke("parse", Array.from(arguments));
  }
}
class AbsArgs extends ScriptableGlobal {
  static type = "args";
  get plainTexts() {
    return this._get("plainTexts");
  }
  set plainTexts(value) {
    this._set("plainTexts", value);
  }
  get urls() {
    return this._get("urls");
  }
  set urls(value) {
    this._set("urls", value);
  }
  get fileURLs() {
    return this._get("fileURLs");
  }
  set fileURLs(value) {
    this._set("fileURLs", value);
  }
  get images() {
    return this._get("images");
  }
  set images(value) {
    this._set("images", value);
  }
  get queryParameters() {
    return this._get("queryParameters");
  }
  set queryParameters(value) {
    this._set("queryParameters", value);
  }
  get shortcutParameter() {
    return this._get("shortcutParameter");
  }
  set shortcutParameter(value) {
    this._set("shortcutParameter", value);
  }
  get widgetParameter() {
    return this._get("widgetParameter");
  }
  set widgetParameter(value) {
    this._set("widgetParameter", value);
  }
  get notification() {
    return this._get("notification");
  }
  set notification(value) {
    this._set("notification", value);
  }
}
class AbsConfig extends ScriptableGlobal {
  static type = "config";
  get runsInApp() {
    return this._get("runsInApp");
  }
  set runsInApp(value) {
    this._set("runsInApp", value);
  }
  get runsInActionExtension() {
    return this._get("runsInActionExtension");
  }
  set runsInActionExtension(value) {
    this._set("runsInActionExtension", value);
  }
  get runsWithSiri() {
    return this._get("runsWithSiri");
  }
  set runsWithSiri(value) {
    this._set("runsWithSiri", value);
  }
  get runsInWidget() {
    return this._get("runsInWidget");
  }
  set runsInWidget(value) {
    this._set("runsInWidget", value);
  }
  get runsInAccessoryWidget() {
    return this._get("runsInAccessoryWidget");
  }
  set runsInAccessoryWidget(value) {
    this._set("runsInAccessoryWidget", value);
  }
  get runsInNotification() {
    return this._get("runsInNotification");
  }
  set runsInNotification(value) {
    this._set("runsInNotification", value);
  }
  get runsFromHomeScreen() {
    return this._get("runsFromHomeScreen");
  }
  set runsFromHomeScreen(value) {
    this._set("runsFromHomeScreen", value);
  }
  get widgetFamily() {
    return this._get("widgetFamily");
  }
  set widgetFamily(value) {
    this._set("widgetFamily", value);
  }
}
class AbsConsole extends ScriptableGlobal {
  static type = "console";
  log(message) {
    return this._invoke("log", [message]);
  }
  warn(message) {
    return this._invoke("warn", [message]);
  }
  error(message) {
    return this._invoke("error", [message]);
  }
}
class AbsDevice extends ScriptableGlobal {
  static type = "Device";
  name() {
    return this._invoke("name", []);
  }
  systemName() {
    return this._invoke("systemName", []);
  }
  systemVersion() {
    return this._invoke("systemVersion", []);
  }
  model() {
    return this._invoke("model", []);
  }
  isPhone() {
    return this._invoke("isPhone", []);
  }
  isPad() {
    return this._invoke("isPad", []);
  }
  screenSize() {
    return this._invoke("screenSize", []);
  }
  screenResolution() {
    return this._invoke("screenResolution", []);
  }
  screenScale() {
    return this._invoke("screenScale", []);
  }
  screenBrightness() {
    return this._invoke("screenBrightness", []);
  }
  isInPortrait() {
    return this._invoke("isInPortrait", []);
  }
  isInPortraitUpsideDown() {
    return this._invoke("isInPortraitUpsideDown", []);
  }
  isInLandscapeLeft() {
    return this._invoke("isInLandscapeLeft", []);
  }
  isInLandscapeRight() {
    return this._invoke("isInLandscapeRight", []);
  }
  isFaceUp() {
    return this._invoke("isFaceUp", []);
  }
  isFaceDown() {
    return this._invoke("isFaceDown", []);
  }
  batteryLevel() {
    return this._invoke("batteryLevel", []);
  }
  isDischarging() {
    return this._invoke("isDischarging", []);
  }
  isCharging() {
    return this._invoke("isCharging", []);
  }
  isFullyCharged() {
    return this._invoke("isFullyCharged", []);
  }
  preferredLanguages() {
    return this._invoke("preferredLanguages", []);
  }
  locale() {
    return this._invoke("locale", []);
  }
  language() {
    return this._invoke("language", []);
  }
  isUsingDarkAppearance() {
    return this._invoke("isUsingDarkAppearance", []);
  }
  volume() {
    return this._invoke("volume", []);
  }
  setScreenBrightness(percentage) {
    return this._invoke("setScreenBrightness", [percentage]);
  }
}
class AbsDictation extends ScriptableGlobal {
  static type = "Dictation";
  start(locale) {
    return this._invoke("start", [locale]);
  }
}
class AbsDocumentPicker extends ScriptableGlobal {
  static type = "DocumentPicker";
  open(types) {
    return this._invoke("open", [types]);
  }
  openFile() {
    return this._invoke("openFile", []);
  }
  openFolder() {
    return this._invoke("openFolder", []);
  }
  export(path) {
    return this._invoke("export", [path]);
  }
  exportString(content, name) {
    return this._invoke("exportString", [content, name]);
  }
  exportImage(image, name) {
    return this._invoke("exportImage", [image, name]);
  }
  exportData(data, name) {
    return this._invoke("exportData", [data, name]);
  }
}
class AbsKeychain extends ScriptableGlobal {
  static type = "Keychain";
  contains(key) {
    return this._invoke("contains", [key]);
  }
  set(key, value) {
    return this._invoke("set", [key, value]);
  }
  get(key) {
    return this._invoke("get", [key]);
  }
  remove(key) {
    return this._invoke("remove", [key]);
  }
}
class AbsLocation extends ScriptableGlobal {
  static type = "Location";
  current() {
    return this._invoke("current", []);
  }
  setAccuracyToBest() {
    return this._invoke("setAccuracyToBest", []);
  }
  setAccuracyToTenMeters() {
    return this._invoke("setAccuracyToTenMeters", []);
  }
  setAccuracyToHundredMeters() {
    return this._invoke("setAccuracyToHundredMeters", []);
  }
  setAccuracyToKilometer() {
    return this._invoke("setAccuracyToKilometer", []);
  }
  setAccuracyToThreeKilometers() {
    return this._invoke("setAccuracyToThreeKilometers", []);
  }
  reverseGeocode(latitude, longitude, locale) {
    return this._invoke("reverseGeocode", [latitude, longitude, locale]);
  }
}
class AbsModule extends ScriptableGlobal {
  static type = "module";
  get filename() {
    return this._get("filename");
  }
  set filename(value) {
    this._set("filename", value);
  }
  get exports() {
    return this._get("exports");
  }
  set exports(value) {
    this._set("exports", value);
  }
}
class AbsPasteboard extends ScriptableGlobal {
  static type = "Pasteboard";
  copy(string) {
    return this._invoke("copy", [string]);
  }
  paste() {
    return this._invoke("paste", []);
  }
  copyString(string) {
    return this._invoke("copyString", [string]);
  }
  pasteString() {
    return this._invoke("pasteString", []);
  }
  copyImage(image) {
    return this._invoke("copyImage", [image]);
  }
  pasteImage() {
    return this._invoke("pasteImage", []);
  }
}
class AbsPhotos extends ScriptableGlobal {
  static type = "Photos";
  fromLibrary() {
    return this._invoke("fromLibrary", []);
  }
  fromCamera() {
    return this._invoke("fromCamera", []);
  }
  latestPhoto() {
    return this._invoke("latestPhoto", []);
  }
  latestPhotos(count) {
    return this._invoke("latestPhotos", [count]);
  }
  latestScreenshot() {
    return this._invoke("latestScreenshot", []);
  }
  latestScreenshots(count) {
    return this._invoke("latestScreenshots", [count]);
  }
  removeLatestPhoto() {
    return this._invoke("removeLatestPhoto", []);
  }
  removeLatestPhotos(count) {
    return this._invoke("removeLatestPhotos", [count]);
  }
  removeLatestScreenshot() {
    return this._invoke("removeLatestScreenshot", []);
  }
  removeLatestScreenshots(count) {
    return this._invoke("removeLatestScreenshots", [count]);
  }
  save(image) {
    return this._invoke("save", [image]);
  }
}
class AbsQuickLook extends ScriptableGlobal {
  static type = "QuickLook";
  present(item, fullscreen) {
    return this._invoke("present", [item, fullscreen]);
  }
}
class AbsSafari extends ScriptableGlobal {
  static type = "Safari";
  openInApp(url, fullscreen) {
    return this._invoke("openInApp", [url, fullscreen]);
  }
  open(url) {
    return this._invoke("open", [url]);
  }
}
class AbsScript extends ScriptableGlobal {
  static type = "Script";
  name() {
    return this._invoke("name", []);
  }
  complete() {
    return this._invoke("complete", []);
  }
  setShortcutOutput(value) {
    return this._invoke("setShortcutOutput", [value]);
  }
  setWidget(widget) {
    return this._invoke("setWidget", [widget]);
  }
}
class AbsShareSheet extends ScriptableGlobal {
  static type = "ShareSheet";
  present(activityItems) {
    return this._invoke("present", [activityItems]);
  }
}
class AbsSpeech extends ScriptableGlobal {
  static type = "Speech";
  speak(text) {
    return this._invoke("speak", [text]);
  }
}
class AbsURLScheme extends ScriptableGlobal {
  static type = "URLScheme";
  forOpeningScript() {
    return this._invoke("forOpeningScript", []);
  }
  forOpeningScriptSettings() {
    return this._invoke("forOpeningScriptSettings", []);
  }
  forRunningScript() {
    return this._invoke("forRunningScript", []);
  }
}
class AbsUUID extends ScriptableGlobal {
  static type = "UUID";
  string() {
    return this._invoke("string", []);
  }
}

export { AbsAlert, AbsArgs, AbsCalendar, AbsCalendarEvent, AbsCallbackURL, AbsColor, AbsConfig, AbsConsole, AbsContact, AbsContactsContainer, AbsContactsGroup, AbsData, AbsDateFormatter, AbsDatePicker, AbsDevice, AbsDictation, AbsDocumentPicker, AbsDrawContext, AbsFileManager, AbsFont, AbsImage, AbsKeychain, AbsLinearGradient, AbsListWidget, AbsLocation, AbsMail, AbsMessage, AbsModule, AbsNotification, AbsPasteboard, AbsPath, AbsPhotos, AbsPoint, AbsQuickLook, AbsRect, AbsRecurrenceRule, AbsRelativeDateTimeFormatter, AbsReminder, AbsRequest, AbsSFSymbol, AbsSafari, AbsScript, AbsShareSheet, AbsSize, AbsSpeech, AbsTextField, AbsTimer, AbsUITable, AbsUITableCell, AbsUITableRow, AbsURLScheme, AbsUUID, AbsWebView, AbsWidgetDate, AbsWidgetImage, AbsWidgetSpacer, AbsWidgetStack, AbsWidgetText, AbsXMLParser, ScriptableBase, ScriptableGlobal, ScriptableObject };
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map